
from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.base.base_entity import BaseEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class PropertyCollector(BaseEntity):
    '''The PropertyCollector managed object retrieves and detects changes to the
    properties of other managed objects. The RetrievePropertiesEx method provides
    one-time property retrieval. The WaitForUpdatesEx method provides incremental
    change detection and supports both polling and notification.For change
    detection a client creates one or more filters to specify the subset of managed
    objects in which the client is interested. Filters keep per-session state to
    track incremental changes. Because this state is per-session:* A session cannot
    share its PropertyCollector filters with other sessions * two different clients
    can share the same session, and so can share the same filters, but this is not
    recommended * When a session terminates, the associated PropertyCollector
    filters are automatically destroyed.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.PropertyCollector):
        super(PropertyCollector, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def filter(self):
        '''The filters that this PropertyCollector uses to determine the list of
        properties for which it detects incremental changes.'''
        return self.update('filter')

    
    
    def CancelRetrievePropertiesEx(self, token):
        '''Discards remaining results from a retrieval started by RetrievePropertiesEx on
        the same session on the same PropertyCollector.
        
        :param token: the token returned in the previous RetrieveResult returned on the same session by the same PropertyCollector.
        
        '''
        return self.delegate("CancelRetrievePropertiesEx")(token)
    
    def CancelWaitForUpdates(self):
        '''Attempts to cancel outstanding calls to WaitForUpdates or WaitForUpdatesEx in
        the current session. If an update calculation is in process this method has no
        effect. If an update calculation is not in process any waiting calls complete
        quickly and report a RequestCanceled fault.
        
        '''
        return self.delegate("CancelWaitForUpdates")()
    
    def CheckForUpdates(self, version=None):
        '''<b>Deprecated.</b> <i>As of vSphere API 4.1, use WaitForUpdatesEx with a
        maxWaitSeconds of 0.</i> Checks for updates on properties specified by the
        union of all current filters. If no updates are pending, this method returns
        null.
        
        :param version: The data version currently known to the client. The value must be either * the special initial version (an empty string) * a data version returned from CheckForUpdates or WaitForUpdates by the same PropertyCollector on the same session. * a non-truncated data version returned from WaitForUpdatesEx by the same PropertyCollector on the same session.
        
        '''
        return self.delegate("CheckForUpdates")(version)
    
    def ContinueRetrievePropertiesEx(self, token):
        '''Retrieves additional results from a retrieval started by RetrievePropertiesEx
        on the same session on the same PropertyCollector.
        
        :param token: the token returned in the previous RetrieveResult returned on the same session by the same PropertyCollector.
        
        '''
        return self.delegate("ContinueRetrievePropertiesEx")(token)
    
    def CreateFilter(self, spec, partialUpdates):
        '''Creates a new filter for the given set of managed objects.
        
        :param spec: The specifications for the filter.
        
        :param partialUpdates: Flag to specify whether a change to a nested property should report only the nested change or the entire specified property value. If the value is true, a change should report only the nested property. If the value is false, a change should report the enclosing property named in the filter.
        
        '''
        return self.delegate("CreateFilter")(spec, partialUpdates)
    
    def CreatePropertyCollector(self):
        '''Creates a new session-specific PropertyCollector that can be used to retrieve
        property updates independent of any other PropertyCollector. The newly created
        PropertyCollector is not tied to the creating PropertyCollector in any way and
        exists until it is destroyed by a call to DestroyPropertyCollector or until the
        session on which the PropertyCollector was created is closed. This is in
        contrast to the default PropertyCollector, which always exists, but still has
        session-specific data such as filters and unfinished update calculations that
        are discarded when the associated session is closed.Creates a new session-
        specific PropertyCollector that can be used to retrieve property updates
        independent of any other PropertyCollector. The newly created PropertyCollector
        is not tied to the creating PropertyCollector in any way and exists until it is
        destroyed by a call to DestroyPropertyCollector or until the session on which
        the PropertyCollector was created is closed. This is in contrast to the default
        PropertyCollector, which always exists, but still has session-specific data
        such as filters and unfinished update calculations that are discarded when the
        associated session is closed.Creates a new session-specific PropertyCollector
        that can be used to retrieve property updates independent of any other
        PropertyCollector. The newly created PropertyCollector is not tied to the
        creating PropertyCollector in any way and exists until it is destroyed by a
        call to DestroyPropertyCollector or until the session on which the
        PropertyCollector was created is closed. This is in contrast to the default
        PropertyCollector, which always exists, but still has session-specific data
        such as filters and unfinished update calculations that are discarded when the
        associated session is closed.Creates a new session-specific PropertyCollector
        that can be used to retrieve property updates independent of any other
        PropertyCollector. The newly created PropertyCollector is not tied to the
        creating PropertyCollector in any way and exists until it is destroyed by a
        call to DestroyPropertyCollector or until the session on which the
        PropertyCollector was created is closed. This is in contrast to the default
        PropertyCollector, which always exists, but still has session-specific data
        such as filters and unfinished update calculations that are discarded when the
        associated session is closed.
        
        '''
        return self.delegate("CreatePropertyCollector")()
    
    def DestroyPropertyCollector(self):
        '''Destroys this PropertyCollector.Destroys this PropertyCollector.Destroys this
        PropertyCollector.
        
        '''
        return self.delegate("DestroyPropertyCollector")()
    
    def RetrieveProperties(self, specSet):
        '''<b>Deprecated.</b> <i>As of vSphere API 4.1, use RetrievePropertiesEx.</i>
        Retrieves the specified properties of the specified managed objects.
        
        :param specSet: Specifies the properties to retrieve.
        
        '''
        return self.delegate("RetrieveProperties")(specSet)
    
    def RetrievePropertiesEx(self, specSet, options):
        '''Retrieves the specified properties of the specified managed objects.Retrieves
        the specified properties of the specified managed objects.Retrieves the
        specified properties of the specified managed objects.
        
        :param specSet: Specifies the properties to retrieve.
        
        :param options: Additional method options. If omitted, equivalent to an options argument with no fields set.
        
        '''
        return self.delegate("RetrievePropertiesEx")(specSet, options)
    
    def WaitForUpdates(self, version=None):
        '''<b>Deprecated.</b> <i>As of vSphere API 4.1, use WaitForUpdatesEx.</i>
        Calculate the set of updates for each existing filter in the session, returning
        when at least one filter has updates.
        
        :param version: The data version currently known to the client. The value must be either * the special initial version (an empty string) * a data version returned from CheckForUpdates or WaitForUpdates by the same PropertyCollector on the same session * a non-truncated data version returned from WaitForUpdatesEx by the same PropertyCollector on the same session.
        
        '''
        return self.delegate("WaitForUpdates")(version)
    
    def WaitForUpdatesEx(self, version=None, options=None):
        '''Calculate the set of updates for each existing filter in the session.Calculate
        the set of updates for each existing filter in the session.Calculate the set of
        updates for each existing filter in the session.
        
        :param version: The data version currently known to the client. The value must be either * the special initial data version (an empty string), * a data version returned from CheckForUpdates or WaitForUpdates * a non-truncated data version returned from WaitForUpdatesEx * a truncated data version returned from the last call to WaitForUpdatesEx with no intervening calls to WaitForUpdates or CheckForUpdates.
        
        :param options: Additional options controlling the change calculation. If omitted, equivalent to an options argument with no fields set.
        
        '''
        return self.delegate("WaitForUpdatesEx")(version, options)



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def DasAgentUnavailableEvent(vim, *args, **kwargs):
    '''This event records that VirtualCenter cannot contact any primary host in this
    HA cluster. HA designates some hosts as primary hosts in the HA cluster. When
    adding a new host to an existing cluster, HA needs to contact one of the
    primary hosts to finish the configuration. VirtualCenter has lost contact with
    all primary nodes in the connected state. Attempts to configure HA on a host in
    this cluster will fail until a DasAgentFoundEvent is logged or unless this is
    the first node to be configured. For example, if all the other hosts are
    disconnected first.'''

    obj = vim.client.factory.create('{urn:vim25}DasAgentUnavailableEvent')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 4:
        raise IndexError('Expected at least 5 arguments got: %d' % len(args))

    required = [ 'chainId', 'createdTime', 'key', 'userName' ]
    optional = [ 'changeTag', 'computeResource', 'datacenter', 'ds', 'dvs',
        'fullFormattedMessage', 'host', 'net', 'vm', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

WeekOfMonth = Enum(
    'first',
    'fourth',
    'last',
    'second',
    'third',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def EVCMode(vim, *args, **kwargs):
    '''The EVCMode data object describes an Enhanced vMotion Compatibility mode. An
    EVC mode is associated with a set of CPU features. A vCenter Server defines the
    available EVC modes. You use them to establish a common set of features for
    compatibility between hosts in a cluster. An EVC-enabled cluster supports safe
    vMotion of virtual machines across a range of CPU generations. You must use the
    vSphere Client to configure EVC.When you add a host to an EVC-enabled cluster,
    the vCenter Server determines the CPU compatibility to preserve vMotion
    compatibility within the cluster. If the host CPU is compatible with those
    already in the cluster, the Server adds the host to the cluster and configures
    it for compatible operation. Hosts that are not compatible are not allowed to
    join the cluster.The inherited key property is a string value that uniquely
    identifies an EVC mode. The vCenter Server assigns the key value; the vSphere
    API uses the key to identify modes in summary and information objects:The
    inherited label and summary properties are human-readable strings.You can use
    the track and vendorTier properties to determine feature-superset relationships
    between modes without examining the individual feature bits in
    guaranteedCPUFeatures. The CPU feature baseline of mode A is a superset of mode
    B's baseline if and only if:Use the track and vendorTier properties only for
    the purpose of feature-superset calculations as described above. Do not use
    them to infer the presence or absence of specific features. The property values
    for a given mode may change across releases as the set of available EVC modes
    changes, to better represent mode relationships.'''

    obj = vim.client.factory.create('{urn:vim25}EVCMode')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 6:
        raise IndexError('Expected at least 7 arguments got: %d' % len(args))

    required = [ 'track', 'vendor', 'vendorTier', 'key', 'label', 'summary' ]
    optional = [ 'guaranteedCPUFeatures', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.managed_entity import ManagedEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class VirtualMachine(ManagedEntity):
    '''VirtualMachine is the managed object type for manipulating virtual machines,
    including templates that can be deployed (repeatedly) as new virtual machines.
    This type provides methods for configuring and controlling a virtual
    machine.VirtualMachine extends the ManagedEntity type because virtual machines
    are part of a virtual infrastructure inventory. The parent of a virtual machine
    must be a folder, and a virtual machine has no children.Destroying a virtual
    machine disposes of all associated storage, including the virtual disks. To
    remove a virtual machine while retaining its virtual disk storage, a client
    must remove the virtual disks from the virtual machine before destroying it.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.VirtualMachine):
        super(VirtualMachine, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def capability(self):
        '''Information about the runtime capabilities of this virtual machine.'''
        return self.update('capability')
    @property
    def config(self):
        '''Configuration of this virtual machine, including the name and UUID.'''
        return self.update('config')
    @property
    def datastore(self):
        '''A collection of references to the subset of datastore objects in the datacenter
        that is used by this virtual machine.'''
        return self.update('datastore')
    @property
    def environmentBrowser(self):
        '''The current virtual machine's environment browser object. This contains
        information on all the configurations that can be used on the virtual machine.
        This is identical to the environment browser on the ComputeResource to which
        this virtual machine belongs.'''
        return self.update('environmentBrowser')
    @property
    def guest(self):
        '''Information about VMware Tools and about the virtual machine from the
        perspective of VMware Tools. Information about the guest operating system is
        available in VirtualCenter. Guest operating system information reflects the
        last known state of the virtual machine. For powered on machines, this is
        current information. For powered off machines, this is the last recorded state
        before the virtual machine was powered off.'''
        return self.update('guest')
    @property
    def guestHeartbeatStatus(self):
        '''The guest heartbeat. The heartbeat status is classified as: * gray - VMware
        Tools are not installed or not running. * red - No heartbeat. Guest operating
        system may have stopped responding. * yellow - Intermittent heartbeat. May be
        due to guest load. * green - Guest operating system is responding normally. The
        guest heartbeat is a statistics metric. Alarms can be configured on this metric
        to trigger emails or other actions.'''
        return self.update('guestHeartbeatStatus')
    @property
    def layout(self):
        '''Detailed information about the files that comprise this virtual machine.'''
        return self.update('layout')
    @property
    def layoutEx(self):
        '''Detailed information about the files that comprise this virtual machine.'''
        return self.update('layoutEx')
    @property
    def network(self):
        '''A collection of references to the subset of network objects in the datacenter
        that is used by this virtual machine.'''
        return self.update('network')
    @property
    def parentVApp(self):
        '''Reference to the parent vApp.'''
        return self.update('parentVApp')
    @property
    def resourceConfig(self):
        '''The resource configuration for a virtual machine. The shares in this
        specification are evaluated relative to the resource pool to which it is
        assigned. This will return null if the product the virtual machine is
        registered on does not support resource configuration.'''
        return self.update('resourceConfig')
    @property
    def resourcePool(self):
        '''The current resource pool that specifies resource allocation for this virtual
        machine.'''
        return self.update('resourcePool')
    @property
    def rootSnapshot(self):
        '''The roots of all snapshot trees for the virtual machine.'''
        return self.update('rootSnapshot')
    @property
    def runtime(self):
        '''Execution state and history for this virtual machine.'''
        return self.update('runtime')
    @property
    def snapshot(self):
        '''Current snapshot and tree. The property is valid if snapshots have been created
        for this virtual machine.'''
        return self.update('snapshot')
    @property
    def storage(self):
        '''Storage space used by the virtual machine, split by datastore. Can be
        explicitly refreshed by the RefreshStorageInfo operation.'''
        return self.update('storage')
    @property
    def summary(self):
        '''Basic information about this virtual machine. This includes: * runtimeInfo *
        guest * basic configuration * alarms * performance information'''
        return self.update('summary')

    
    
    def AcquireMksTicket(self):
        '''<b>Deprecated.</b> <i>As of vSphere API 4.1, use AcquireTicket instead.</i>
        Creates and returns a one-time credential used in establishing a remote mouse-
        keyboard-screen connection to this virtual machine. The correct function of
        this method depends on being able to retrieve TCP binding information about the
        server end of the client connection that is requesting the ticket. If such
        information is not available, the NotSupported fault is thrown. This method is
        appropriate for SOAP and authenticated connections, which are both TCP-based
        connections.
        
        '''
        return self.delegate("AcquireMksTicket")()
    
    def AcquireTicket(self, ticketType):
        '''Creates and returns a one-time credential used in establishing a specific
        connection to this virtual machine, for example, a ticket type of mks can be
        used to establish a remote mouse-keyboard-screen connection.Creates and returns
        a one-time credential used in establishing a specific connection to this
        virtual machine, for example, a ticket type of mks can be used to establish a
        remote mouse-keyboard-screen connection.Creates and returns a one-time
        credential used in establishing a specific connection to this virtual machine,
        for example, a ticket type of mks can be used to establish a remote mouse-
        keyboard-screen connection.Creates and returns a one-time credential used in
        establishing a specific connection to this virtual machine, for example, a
        ticket type of mks can be used to establish a remote mouse-keyboard-screen
        connection.
        
        :param ticketType: The type of service to acquire, the set of possible values is described in VirtualMachineTicketType.
        
        '''
        return self.delegate("AcquireTicket")(ticketType)
    
    def AnswerVM(self, questionId, answerChoice):
        '''Responds to a question that is blocking this virtual machine.
        
        :param questionId: The value from QuestionInfo.id that identifies the question to answer.
        
        :param answerChoice: The contents of the QuestionInfo.choice.value array element that identifies the desired answer.
        
        '''
        return self.delegate("AnswerVM")(questionId, answerChoice)
    
    def CheckCustomizationSpec(self, spec):
        '''Checks the customization specification against the virtual machine
        configuration. For example, this is used on a source virtual machine before a
        clone operation to catch customization failure before the disk copy. This
        checks the specification's internal consistency as well as for compatibility
        with this virtual machine's configuration.
        
        :param spec: The customization specification to check.
        
        '''
        return self.delegate("CheckCustomizationSpec")(spec)
    
    def CloneVM_Task(self, folder, name, spec):
        '''Creates a clone of this virtual machine. If the virtual machine is used as a
        template, this method corresponds to the deploy command.Creates a clone of this
        virtual machine. If the virtual machine is used as a template, this method
        corresponds to the deploy command.Creates a clone of this virtual machine. If
        the virtual machine is used as a template, this method corresponds to the
        deploy command.Creates a clone of this virtual machine. If the virtual machine
        is used as a template, this method corresponds to the deploy command.Creates a
        clone of this virtual machine. If the virtual machine is used as a template,
        this method corresponds to the deploy command.Creates a clone of this virtual
        machine. If the virtual machine is used as a template, this method corresponds
        to the deploy command.
        
        :param folder: The location of the new virtual machine.
        
        :param name: The name of the new virtual machine.
        
        :param spec: Specifies how to clone the virtual machine.
        
        '''
        return self.delegate("CloneVM_Task")(folder, name, spec)
    
    def ConsolidateVMDisks_Task(self):
        '''Consolidate the virtual disk files of the virtual machine by finding
        hierarchies of redo logs that can be combined without violating data
        dependency. The redundant redo logs after merging are then deleted.
        Consolidation improves I/O performance since less number of virtual disk files
        need to be traversed; it also reduces the storage usage. However additional
        space is temporarily required to perform the operation. Use
        EstimateStorageForConsolidateSnapshots_Task to estimate the temporary space
        required. Consolidation can be I/O intensive, it is advisable to invoke this
        operation when guest is not under heavy I/O usage.
        
        '''
        return self.delegate("ConsolidateVMDisks_Task")()
    
    def CreateScreenshot_Task(self):
        '''Create a screen shot of a virtual machine.
        
        '''
        return self.delegate("CreateScreenshot_Task")()
    
    def CreateSecondaryVM_Task(self, host=None):
        '''Creates a secondary virtual machine to be part of this fault tolerant
        group.Creates a secondary virtual machine to be part of this fault tolerant
        group.Creates a secondary virtual machine to be part of this fault tolerant
        group.
        
        :param host: The host where the secondary virtual machine is to be created and powered on. If no host is specified, a compatible host will be selected by the system. If a host cannot be found for the secondary or the specified host is not suitable, the secondary will not be created and a fault will be returned.
        
        '''
        return self.delegate("CreateSecondaryVM_Task")(host)
    
    def CreateSnapshot_Task(self, name, memory, quiesce, description=None):
        '''Creates a new snapshot of this virtual machine. As a side effect, this updates
        the current snapshot.Creates a new snapshot of this virtual machine. As a side
        effect, this updates the current snapshot.Creates a new snapshot of this
        virtual machine. As a side effect, this updates the current snapshot.
        
        :param name: The name for this snapshot. The name need not be unique for this virtual machine.
        
        :param description: A description for this snapshot. If omitted, a default description may be provided.
        
        :param memory: If TRUE, a dump of the internal state of the virtual machine (basically a memory dump) is included in the snapshot. Memory snapshots consume time and resources, and thus take longer to create. When set to FALSE, the power state of the snapshot is set to powered off.
        
        :param quiesce: If TRUE and the virtual machine is powered on when the snapshot is taken, VMware Tools is used to quiesce the file system in the virtual machine. This assures that a disk snapshot represents a consistent state of the guest file systems. If the virtual machine is powered off or VMware Tools are not available, the quiesce flag is ignored.
        
        '''
        return self.delegate("CreateSnapshot_Task")(name, description, memory, quiesce)
    
    def CustomizeVM_Task(self, spec):
        '''Customizes a virtual machine's guest operating system.
        
        :param spec: The customization specification object.
        
        '''
        return self.delegate("CustomizeVM_Task")(spec)
    
    def DefragmentAllDisks(self):
        '''Defragment all virtual disks attached to this virtual machine.
        
        '''
        return self.delegate("DefragmentAllDisks")()
    
    def DisableSecondaryVM_Task(self, vm):
        '''Disables the specified secondary virtual machine in this fault tolerant group.
        The specified secondary will not be automatically started on a subsequent
        power-on of the primary virtual machine. This operation could leave the primary
        virtual machine in a non-fault tolerant state.
        
        :param vm: The secondary virtual machine specified will be disabed. This field must specify a secondary virtual machine that is part of the fault tolerant group that this virtual machine is currently associated with. It can only be invoked from the primary virtual machine in the group.
        
        '''
        return self.delegate("DisableSecondaryVM_Task")(vm)
    
    def EnableSecondaryVM_Task(self, vm, host=None):
        '''Enables the specified secondary virtual machine in this fault tolerant
        group.Enables the specified secondary virtual machine in this fault tolerant
        group.Enables the specified secondary virtual machine in this fault tolerant
        group.
        
        :param vm: The secondary virtual machine specified will be enabled. This field must specify a secondary virtual machine that is part of the fault tolerant group that this virtual machine is currently associated with. It can only be invoked from the primary virtual machine in the group.
        
        :param host: The host on which the secondary virtual machine is to be enabled and possibly powered on. If no host is specified, a compatible host will be selected by the system. If the secondary virtual machine is not compatible with the specified host, the secondary will not be re-enabled and a fault will be returned.
        
        '''
        return self.delegate("EnableSecondaryVM_Task")(vm, host)
    
    def EstimateStorageForConsolidateSnapshots_Task(self):
        '''Estimate the temporary space required to consolidation disk files. The
        estimation is a lower bound if the childmost writable disk file will be
        consolidated for an online virtual machine, it is accurate for all other
        situations. This is because the space requirement depending on the size of the
        childmost disk file and how write intensive the guest is.Estimate the temporary
        space required to consolidation disk files. The estimation is a lower bound if
        the childmost writable disk file will be consolidated for an online virtual
        machine, it is accurate for all other situations. This is because the space
        requirement depending on the size of the childmost disk file and how write
        intensive the guest is.
        
        '''
        return self.delegate("EstimateStorageForConsolidateSnapshots_Task")()
    
    def ExportVm(self):
        '''Obtains an export lease on this virtual machine. The export lease contains a
        list of URLs for the virtual disks for this virtual machine, as well as a
        ticket giving access to the URLs.Obtains an export lease on this virtual
        machine. The export lease contains a list of URLs for the virtual disks for
        this virtual machine, as well as a ticket giving access to the URLs.
        
        '''
        return self.delegate("ExportVm")()
    
    def ExtractOvfEnvironment(self):
        '''Returns the OVF environment for a virtual machine. If the virtual machine has
        no vApp configuration, an empty string is returned. Also, sensitive information
        is omitted, so this method is not guaranteed to return the complete OVF
        environment.
        
        '''
        return self.delegate("ExtractOvfEnvironment")()
    
    def MakePrimaryVM_Task(self, vm):
        '''Makes the specified secondary virtual machine from this fault tolerant group as
        the primary virtual machine.
        
        :param vm: The secondary virtual machine specified will be made the primary virtual machine. This field must specify a secondary virtual machine that is part of the fault tolerant group that this virtual machine is currently associated with. It can only be invoked from the primary virtual machine in the group.
        
        '''
        return self.delegate("MakePrimaryVM_Task")(vm)
    
    def MarkAsTemplate(self):
        '''Marks a VirtualMachine object as being used as a template. Note: A
        VirtualMachine marked as a template cannot be powered on.
        
        '''
        return self.delegate("MarkAsTemplate")()
    
    def MarkAsVirtualMachine(self, pool, host=None):
        '''Clears the 'isTemplate' flag and reassociates the virtual machine with a
        resource pool and host.
        
        :param pool: Resource pool to associate with the virtual machine.
        
        :param host: The target host on which the virtual machine is intended to run. The host parameter must specify a host that is a member of the ComputeResource indirectly specified by the pool. For a stand-alone host or a cluster with DRS, it can be omitted and the system selects a default.
        
        '''
        return self.delegate("MarkAsVirtualMachine")(pool, host)
    
    def MigrateVM_Task(self, priority, pool=None, host=None, state=None):
        '''Migrates a virtual machine's execution to a specific resource pool or
        host.Migrates a virtual machine's execution to a specific resource pool or
        host.
        
        :param pool: The target resource pool for the virtual machine. If the pool parameter is left unset, the virtual machine's current pool is used as the target pool.
        
        :param host: The target host to which the virtual machine is intended to migrate. The host parameter may be left unset if the compute resource associated with the target pool represents a stand-alone host or a DRS-enabled cluster. In the former case the stand-alone host is used as the target host. In the latter case, the DRS system selects an appropriate target host from the cluster.
        
        :param priority: The task priority (@see vim.VirtualMachine.MovePriority).
        
        :param state: If specified, the virtual machine migrates only if its state matches the specified state.
        
        '''
        return self.delegate("MigrateVM_Task")(pool, host, priority, state)
    
    def MountToolsInstaller(self):
        '''Mounts the VMware Tools CD installer as a CD-ROM for the guest operating
        system. To monitor the status of the tools install, clients should check the
        tools status, toolsVersionStatus and toolsRunningStatus
        
        '''
        return self.delegate("MountToolsInstaller")()
    
    def PowerOffVM_Task(self):
        '''Powers off this virtual machine. If this virtual machine is a fault tolerant
        primary virtual machine, this will result in the secondary virtual machine(s)
        getting powered off as well.
        
        '''
        return self.delegate("PowerOffVM_Task")()
    
    def PowerOnVM_Task(self, host=None):
        '''Powers on this virtual machine. If the virtual machine is suspended, this
        method resumes execution from the suspend point.Powers on this virtual machine.
        If the virtual machine is suspended, this method resumes execution from the
        suspend point.Powers on this virtual machine. If the virtual machine is
        suspended, this method resumes execution from the suspend point.
        
        :param host: (optional) The host where the virtual machine is to be powered on. If no host is specified, the current associated host is used. This field must specify a host that is part of the same compute resource that the virtual machine is currently associated with. If this host is not compatible, the current host association is used.
        
        '''
        return self.delegate("PowerOnVM_Task")(host)
    
    def PromoteDisks_Task(self, unlink, disks=None):
        '''Promotes disks on this virtual machine that have delta disk backings.Promotes
        disks on this virtual machine that have delta disk backings.Promotes disks on
        this virtual machine that have delta disk backings.
        
        :param unlink: If true, then these disks will be unlinked before consolidation.
        
        :param disks: The set of disks that are to be promoted. If this value is unset or the array is empty, all disks which have delta disk backings are promoted.
        
        '''
        return self.delegate("PromoteDisks_Task")(unlink, disks)
    
    def QueryChangedDiskAreas(self, deviceKey, startOffset, changeId, snapshot=None):
        '''Get a list of areas of a virtual disk belonging to this VM that have been
        modified since a well-defined point in the past. The beginning of the change
        interval is identified by "changeId", while the end of the change interval is
        implied by the snapshot ID passed in.Get a list of areas of a virtual disk
        belonging to this VM that have been modified since a well-defined point in the
        past. The beginning of the change interval is identified by "changeId", while
        the end of the change interval is implied by the snapshot ID passed in.
        
        :param snapshot: Snapshot for which changes that have been made sine "changeId" should be computed. If not set, changes are computed against the "current" snapshot of the virtual machine. However, using the "current" snapshot will only work for virtual machines that are powered off.
        
        :param deviceKey: Identifies the virtual disk for which to compute changes.
        
        :param startOffset: Start Offset in bytes at which to start computing changes. Typically, callers will make multiple calls to this function, starting with startOffset 0 and then examine the "length" property in the returned DiskChangeInfo structure, repeatedly calling queryChangedDiskAreas until a map forthe entire virtual disk has been obtained.
        
        :param changeId: Identifyer referring to a point in the past that should be used as the point in time at which to begin including changes to the disk in the result. A typical use case would be a backup application obtaining a changeId from a virtual disk's backing info when performing a backup. When a subsequent incremental backup is to be performed, this change Id can be used to obtain a list of changed areas on disk.
        
        '''
        return self.delegate("QueryChangedDiskAreas")(snapshot, deviceKey, startOffset, changeId)
    
    def QueryFaultToleranceCompatibility(self):
        '''This API can be invoked to determine whether a virtual machine is compatible
        for Fault Tolerance. The API only checks for VM-specific factors that impact
        compatibility for Fault Tolerance. Other requirements for Fault Tolerance such
        as host processor compatibility, logging nic configuration and licensing are
        not covered by this API. The query returns a list of faults, each fault
        corresponding to a specific incompatibility. If a given virtual machine is
        compatible for Fault Tolerance, then the fault list returned will be empty.
        
        '''
        return self.delegate("QueryFaultToleranceCompatibility")()
    
    def QueryUnownedFiles(self):
        '''For all files that belong to the vm, check that the file owner is set to the
        current datastore principal user, as set by
        HostDatastoreSystem.ConfigureDatastorePrincipal
        
        '''
        return self.delegate("QueryUnownedFiles")()
    
    def RebootGuest(self):
        '''Issues a command to the guest operating system asking it to perform a reboot.
        Returns immediately and does not wait for the guest operating system to
        complete the operation.
        
        '''
        return self.delegate("RebootGuest")()
    
    def ReconfigVM_Task(self, spec):
        '''Reconfigures this virtual machine. All the changes in the given configuration
        are applied to the virtual machine as an atomic operation.Reconfigures this
        virtual machine. All the changes in the given configuration are applied to the
        virtual machine as an atomic operation.Reconfigures this virtual machine. All
        the changes in the given configuration are applied to the virtual machine as an
        atomic operation.Reconfigures this virtual machine. All the changes in the
        given configuration are applied to the virtual machine as an atomic
        operation.Reconfigures this virtual machine. All the changes in the given
        configuration are applied to the virtual machine as an atomic
        operation.Reconfigures this virtual machine. All the changes in the given
        configuration are applied to the virtual machine as an atomic
        operation.Reconfigures this virtual machine. All the changes in the given
        configuration are applied to the virtual machine as an atomic operation.
        
        :param spec: The new configuration values.
        
        '''
        return self.delegate("ReconfigVM_Task")(spec)
    
    def RefreshStorageInfo(self):
        '''Explicitly refreshes the storage information of this virtual machine, updating
        properties storage, layoutEx and storage.
        
        '''
        return self.delegate("RefreshStorageInfo")()
    
    def reloadVirtualMachineFromPath_Task(self, configurationPath):
        '''Reloads the configuration for this virtual machine from a given datastore path.
        This is equivalent to unregistering and registering the virtual machine from a
        different path. The virtual machine's hardware configuration, snapshots,
        guestinfo variables etc. will be replaced based on the new configuration file.
        Other information associated with the virtual machine object, such as events
        and permissions, will be preserved.Reloads the configuration for this virtual
        machine from a given datastore path. This is equivalent to unregistering and
        registering the virtual machine from a different path. The virtual machine's
        hardware configuration, snapshots, guestinfo variables etc. will be replaced
        based on the new configuration file. Other information associated with the
        virtual machine object, such as events and permissions, will be
        preserved.Reloads the configuration for this virtual machine from a given
        datastore path. This is equivalent to unregistering and registering the virtual
        machine from a different path. The virtual machine's hardware configuration,
        snapshots, guestinfo variables etc. will be replaced based on the new
        configuration file. Other information associated with the virtual machine
        object, such as events and permissions, will be preserved.
        
        :param configurationPath: 
        
        '''
        return self.delegate("reloadVirtualMachineFromPath_Task")(configurationPath)
    
    def RelocateVM_Task(self, spec, priority=None):
        '''Relocates a virtual machine's virtual disks to a specific location; optionally
        moves the virtual machine to a different host as well.Relocates a virtual
        machine's virtual disks to a specific location; optionally moves the virtual
        machine to a different host as well.Relocates a virtual machine's virtual disks
        to a specific location; optionally moves the virtual machine to a different
        host as well.
        
        :param spec: The specification of where to relocate the virtual machine.
        
        :param priority: The task priority (@see vim.VirtualMachine.MovePriority).vSphere API 4.0
        
        '''
        return self.delegate("RelocateVM_Task")(spec, priority)
    
    def RemoveAllSnapshots_Task(self, consolidate=None):
        '''Remove all the snapshots associated with this virtual machine. If the virtual
        machine does not have any snapshots, then this operation simply returns
        successfully.
        
        :param consolidate: (optional) If set to true, the virtual disks of the deleted snapshot will be merged with other disk if possible. Default to true.vSphere API 5.0
        
        '''
        return self.delegate("RemoveAllSnapshots_Task")(consolidate)
    
    def ResetGuestInformation(self):
        '''Clears cached guest information. Guest information can be cleared only if the
        virtual machine is powered off.Clears cached guest information. Guest
        information can be cleared only if the virtual machine is powered off.
        
        '''
        return self.delegate("ResetGuestInformation")()
    
    def ResetVM_Task(self):
        '''Resets power on this virtual machine. If the current state is poweredOn, then
        this method first performs powerOff(hard). Once the power state is poweredOff,
        then this method performs powerOn(option).Resets power on this virtual machine.
        If the current state is poweredOn, then this method first performs
        powerOff(hard). Once the power state is poweredOff, then this method performs
        powerOn(option).
        
        '''
        return self.delegate("ResetVM_Task")()
    
    def RevertToCurrentSnapshot_Task(self, host=None, suppressPowerOn=None):
        '''Reverts the virtual machine to the current snapshot. This is equivalent to
        doing snapshot.currentSnapshot.revert.Reverts the virtual machine to the
        current snapshot. This is equivalent to doing snapshot.currentSnapshot.revert.
        
        :param host: (optional) Choice of host for the virtual machine, in case this operation causes the virtual machine to power on.
        
        :param suppressPowerOn: (optional) If set to true, the virtual machine will not be powered on regardless of the power state when the current snapshot was created. Default to false.vSphere API 4.0
        
        '''
        return self.delegate("RevertToCurrentSnapshot_Task")(host, suppressPowerOn)
    
    def SetDisplayTopology(self, displays):
        '''Sets the console window's display topology as specified.
        
        :param displays: The topology for each monitor that the virtual machine's display must span.
        
        '''
        return self.delegate("SetDisplayTopology")(displays)
    
    def SetScreenResolution(self, width, height):
        '''Sets the console window's resolution as specified.
        
        :param width: The screen width that should be set.
        
        :param height: The screen height that should be set.
        
        '''
        return self.delegate("SetScreenResolution")(width, height)
    
    def ShutdownGuest(self):
        '''Issues a command to the guest operating system asking it to perform a clean
        shutdown of all services. Returns immediately and does not wait for the guest
        operating system to complete the operation.
        
        '''
        return self.delegate("ShutdownGuest")()
    
    def StandbyGuest(self):
        '''Issues a command to the guest operating system asking it to prepare for a
        suspend operation. Returns immediately and does not wait for the guest
        operating system to complete the operation.
        
        '''
        return self.delegate("StandbyGuest")()
    
    def StartRecording_Task(self, name, description=None):
        '''Initiates a recording session on this virtual machine. As a side effect, this
        operation creates a snapshot on the virtual machine, which in turn becomes the
        current snapshot.Initiates a recording session on this virtual machine. As a
        side effect, this operation creates a snapshot on the virtual machine, which in
        turn becomes the current snapshot.
        
        :param name: The name for the snapshot associated with this recording. The name need not be unique for this virtual machine.
        
        :param description: A description for the snapshot associated with this recording. If omitted, a default description may be provided.
        
        '''
        return self.delegate("StartRecording_Task")(name, description)
    
    def StartReplaying_Task(self, replaySnapshot):
        '''Starts a replay session on this virtual machine. As a side effect, this
        operation updates the current snapshot of the virtual machine.Starts a replay
        session on this virtual machine. As a side effect, this operation updates the
        current snapshot of the virtual machine.
        
        :param replaySnapshot: The snapshot from which to start the replay. This snapshot must have been created by a record operation on the virtual machine.
        
        '''
        return self.delegate("StartReplaying_Task")(replaySnapshot)
    
    def StopRecording_Task(self):
        '''Stops a currently active recording session on this virtual machine.Stops a
        currently active recording session on this virtual machine.
        
        '''
        return self.delegate("StopRecording_Task")()
    
    def StopReplaying_Task(self):
        '''Stops a replay session on this virtual machine.Stops a replay session on this
        virtual machine.
        
        '''
        return self.delegate("StopReplaying_Task")()
    
    def SuspendVM_Task(self):
        '''Suspends execution in this virtual machine.
        
        '''
        return self.delegate("SuspendVM_Task")()
    
    def TerminateFaultTolerantVM_Task(self, vm=None):
        '''Terminates the specified secondary virtual machine in a fault tolerant group.
        This can be used to test fault tolerance on a given virtual machine, and should
        be used with care.
        
        :param vm: The secondary virtual machine specified will be terminated, allowing fault tolerance to activate. If no virtual machine is specified, all secondary virtual machines will be terminated. If vm is a primary, InvalidArgument exception is thrown. This field must specify a virtual machine that is part of the fault tolerant group that this virtual machine is currently associated with. It can only be invoked from the primary virtual machine in the group. If the primary virtual machine is terminated, an available secondary virtual machine will be promoted to primary. If no secondary exists, an exception will be thrown and the primary virtual machine will not be terminated. If a secondary virtual machine is terminated, it may be respawned on a potentially different host.
        
        '''
        return self.delegate("TerminateFaultTolerantVM_Task")(vm)
    
    def TurnOffFaultToleranceForVM_Task(self):
        '''Removes all secondary virtual machines associated with the fault tolerant group
        and turns off protection for this virtual machine. This operation can only be
        invoked from the primary virtual machine in the group.
        
        '''
        return self.delegate("TurnOffFaultToleranceForVM_Task")()
    
    def UnmountToolsInstaller(self):
        '''Unmounts VMware Tools installer CD.
        
        '''
        return self.delegate("UnmountToolsInstaller")()
    
    def UnregisterVM(self):
        '''Removes this virtual machine from the inventory without removing any of the
        virtual machine's files on disk. All high-level information stored with the
        management server (ESX Server or VirtualCenter) is removed, including
        information such as statistics, resource pool association, permissions, and
        alarms.Removes this virtual machine from the inventory without removing any of
        the virtual machine's files on disk. All high-level information stored with the
        management server (ESX Server or VirtualCenter) is removed, including
        information such as statistics, resource pool association, permissions, and
        alarms.
        
        '''
        return self.delegate("UnregisterVM")()
    
    def UpgradeTools_Task(self, installerOptions=None):
        '''Begins the tools upgrade process. To monitor the status of the tools install,
        clients should check the tools status, toolsVersionStatus and
        toolsRunningStatus.
        
        :param installerOptions: Command line options passed to the installer to modify the installation procedure for tools.
        
        '''
        return self.delegate("UpgradeTools_Task")(installerOptions)
    
    def UpgradeVM_Task(self, version=None):
        '''Upgrades this virtual machine's virtual hardware to the latest revision that is
        supported by the virtual machine's current host.
        
        :param version: If specified, upgrade to that specified version. If not specified, upgrade to the most current virtual hardware supported on the host.
        
        '''
        return self.delegate("UpgradeVM_Task")(version)



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ActionType = Enum(
    'HostMaintenanceV1',
    'HostPowerV1',
    'MigrationV1',
    'StorageMigrationV1',
    'StoragePlacementV1',
    'VmPowerV1',

)




from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class SoftwareVib(Base):
    '''
    Install, update, remove, or display individual VIB packages
    '''
    moid = 'ha-cli-handler-software-vib'
    def update(self, depot=None, dryrun=None, force=None, maintenancemode=None, noliveinstall=None, nosigcheck=None, proxy=None, vibname=None, viburl=None):
        '''
        Update installed VIBs to newer VIB packages. No new VIBs will be installed, only updates. WARNING: If your installation requires a reboot, you need to disable HA first.
        :param depot: string[], Specifies full remote URLs of the depot index.xml or server file path pointing to an offline bundle .zip file.
        :param dryrun: boolean, Performs a dry-run only. Report the VIB-level operations that would be performed, but do not change anything in the system.
        :param force: boolean, Bypasses checks for package dependencies, conflicts, obsolescence, and acceptance levels. Really not recommended unless you know what you are doing.  Use of this option will result in a warning being displayed in the vSphere Client.
        :param maintenancemode: boolean, Pretends that maintenance mode is in effect. Otherwise, installation will stop for live installs that require maintenance mode. This flag has no effect for reboot required remediations.
        :param noliveinstall: boolean, Forces an install to /altbootbank even if the VIBs are eligible for live installation or removal. Will cause installation to be skipped on PXE-booted hosts.
        :param nosigcheck: boolean, Bypasses acceptance level verification, including signing. Use of this option poses a large security risk and will result in a SECURITY ALERT warning being displayed in the vSphere Client.
        :param proxy: string, Specifies a proxy server to use for HTTP, FTP, and HTTPS connections. The format is proxy-url:port.
        :param vibname: string[], Specifies VIBs from a depot, using one of the following forms: name, name:version, vendor:name, or vendor:name:version. VIB packages which are not updates will be skipped.
        :param viburl: string[], Specifies one or more URLs to VIB packages to update to. http:, https:, ftp:, and file: are all supported. VIB packages which are not updates will be skipped.
        :returns: vim.EsxCLI.software.vib.update.InstallationResult
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.software.vib.Update',
                            depot=depot,
                            dryrun=dryrun,
                            force=force,
                            maintenancemode=maintenancemode,
                            noliveinstall=noliveinstall,
                            nosigcheck=nosigcheck,
                            proxy=proxy,
                            vibname=vibname,
                            viburl=viburl,
                            )
    def list(self, rebootingimage=None):
        '''
        Lists the installed VIB packages
        :param rebootingimage: boolean, Displays information for the ESXi image which becomes active after a reboot, or nothing if the pending-reboot image has not been created yet. If not specified, information from the current ESXi image in memory will be returned.
        :returns: vim.EsxCLI.software.vib.list.VIBSummary[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.software.vib.List',
                            rebootingimage=rebootingimage,
                            )
    def remove(self, vibname, dryrun=None, force=None, maintenancemode=None, noliveinstall=None):
        '''
        Removes VIB packages from the host. WARNING: If your installation requires a reboot, you need to disable HA first.
        :param dryrun: boolean, Performs a dry-run only. Report the VIB-level operations that would be performed, but do not change anything in the system.
        :param force: boolean, Bypasses checks for package dependencies, conflicts, obsolescence, and acceptance levels. Really not recommended unless you know what you are doing. Use of this option will result in a warning being displayed in the vSphere Client.
        :param maintenancemode: boolean, Pretends that maintenance mode is in effect. Otherwise, remove will stop for live removes that require maintenance mode. This flag has no effect for reboot required remediations.
        :param noliveinstall: boolean, Forces an remove to /altbootbank even if the VIBs are eligible for live removal. Will cause installation to be skipped on PXE-booted hosts.
        :param vibname: string[], Specifies one or more VIBs on the host to remove. Must be one of the following forms: name, name:version, vendor:name, vendor:name:version.
        :returns: vim.EsxCLI.software.vib.remove.InstallationResult
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.software.vib.Remove',
                            dryrun=dryrun,
                            force=force,
                            maintenancemode=maintenancemode,
                            noliveinstall=noliveinstall,
                            vibname=vibname,
                            )
    def install(self, depot=None, dryrun=None, force=None, maintenancemode=None, noliveinstall=None, nosigcheck=None, proxy=None, vibname=None, viburl=None):
        '''
        Installs VIB packages from a URL or depot. VIBs may be installed, upgraded, or downgraded. WARNING: If your installation requires a reboot, you need to disable HA first.
        :param depot: string[], Specifies full remote URLs of the depot index.xml or server file path pointing to an offline bundle .zip file.
        :param dryrun: boolean, Performs a dry-run only. Report the VIB-level operations that would be performed, but do not change anything in the system.
        :param force: boolean, Bypasses checks for package dependencies, conflicts, obsolescence, and acceptance levels. Really not recommended unless you know what you are doing. Use of this option will result in a warning being displayed in the vSphere Client.
        :param maintenancemode: boolean, Pretends that maintenance mode is in effect. Otherwise, installation will stop for live installs that require maintenance mode. This flag has no effect for reboot required remediations.
        :param noliveinstall: boolean, Forces an install to /altbootbank even if the VIBs are eligible for live installation or removal. Will cause installation to be skipped on PXE-booted hosts.
        :param nosigcheck: boolean, Bypasses acceptance level verification, including signing. Use of this option poses a large security risk and will result in a SECURITY ALERT warning being displayed in the vSphere Client.
        :param proxy: string, Specifies a proxy server to use for HTTP, FTP, and HTTPS connections. The format is proxy-url:port.
        :param vibname: string[], Specifies VIBs from a depot, using one of the following forms: name, name:version, vendor:name, or vendor:name:version.
        :param viburl: string[], Specifies one or more URLs to VIB packages to install. http:, https:, ftp:, and file: are all supported.
        :returns: vim.EsxCLI.software.vib.install.InstallationResult
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.software.vib.Install',
                            depot=depot,
                            dryrun=dryrun,
                            force=force,
                            maintenancemode=maintenancemode,
                            noliveinstall=noliveinstall,
                            nosigcheck=nosigcheck,
                            proxy=proxy,
                            vibname=vibname,
                            viburl=viburl,
                            )
    def get(self, rebootingimage=None, vibname=None):
        '''
        Displays detailed information about one or more installed VIBs
        :param rebootingimage: boolean, Displays information for the ESXi image which becomes active after a reboot, or nothing if the pending-reboot image has not been created yet. If not specified, information from the current ESXi image in memory will be returned.
        :param vibname: string[], Specifies one or more installed VIBs to display more information about. If this option is not specified, then all of the installed VIBs will be displayed. Must be one of the following forms: name, name:version, vendor:name, or vendor:name:version.
        :returns: vim.EsxCLI.software.vib.get.VIB[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.software.vib.Get',
                            rebootingimage=rebootingimage,
                            vibname=vibname,
                            )   



from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class NetworkNic(Base):
    '''
    Operations having to do with the configuration of Network Interface Card and getting and updating the NIC settings.
    '''
    moid = 'ha-cli-handler-network-nic'
    def down(self, nicname):
        '''
        Bring down the specified network device.
        :param nicname: string, The name of the NIC to configured. This must be one of the cards listed in the nic list command.
        :returns: boolean
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.network.nic.Down',
                            nicname=nicname,
                            )
    def set(self, nicname, auto=None, duplex=None, messagelevel=None, phyaddress=None, port=None, speed=None, transceivertype=None, wakeonlan=None):
        '''
        Set the general options for the specified ethernet device.
        :param auto: boolean, Set the speed and duplexity settings to autonegotiate.
        :param duplex: string, The duplex to set this NIC to. Acceptable values are :  [full, half]
        :param messagelevel: long, Sets the driver message level. Meaning differ per driver.
        :param nicname: string, The name of the NIC to configured. This must be one of the cards listed in the nic list command.
        :param phyaddress: long, Set the PHY address of the device
        :param port: string, Selects device port. Available device ports are 
    aui: Select aui as the device port
    bnc: Select bnc as the device port
    fibre: Select mii as the device port
    mii: Select mii as the device port
    tp: Select tp as the device port

        :param speed: long, The speed to set this NIC to. Acceptable values are :  [10, 100, 1000, 10000]
        :param transceivertype: string, Selects transeiver type. Currently only internal and external can be specified, in the future future types might be added. Available transeiver types are 
    external: Set the transceiver type to external
    internal: Set the transceiver type to internal

        :param wakeonlan: string, Sets Wake-on-LAN options. Not all devices support this. The argument to this option is a string of characters specifying which options to enable. 
p Wake on phy activity
u wake on unicast messages
m Wake on multicast messages
b wake on broadcast messages
a Wake on ARP
g Wake on MagicPacket(tm)
s Enable SecureOn(tm) password for MagicPacket(tm)

        :returns: boolean
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.network.nic.Set',
                            auto=auto,
                            duplex=duplex,
                            messagelevel=messagelevel,
                            nicname=nicname,
                            phyaddress=phyaddress,
                            port=port,
                            speed=speed,
                            transceivertype=transceivertype,
                            wakeonlan=wakeonlan,
                            )
    def list(self):
        '''
        This command will list the Physical NICs currently installed and loaded on the system.
        :returns: vim.EsxCLI.network.nic.list.Nic[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.network.nic.List',
                            )
    def up(self, nicname):
        '''
        Bring up the specified network device.
        :param nicname: string, The name of the NIC to configured. This must be one of the cards listed in the nic list command.
        :returns: boolean
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.network.nic.Up',
                            nicname=nicname,
                            )
    def get(self, nicname):
        '''
        Get the generic configuration of a network device
        :param nicname: string, The name of the NIC to configured. This must be one of the cards listed in the nic list command.
        :returns: vim.EsxCLI.network.nic.get.NICInfo
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.network.nic.Get',
                            nicname=nicname,
                            )   



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostIncompatibleForRecordReplayReason = Enum(
    'processor',
    'product',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def InsufficientFailoverResourcesFault(vim, *args, **kwargs):
    '''This is thrown if an operation would violate the configured failover level of a
    HA cluster.In a HA cluster, virtual machines provide high availability by
    moving among physical machines in the event of a failure. HA Admission Control
    ensures that the total resource requirements for the set of virtual machines in
    a HA cluster does not exceed the resources that would be available in the
    worst-case scenario failure. If HA Admission Control is not used, physical
    machines may have insufficient resources to provide the expected level of
    service.This fault indicates that the virtual machine operation you attempted
    would have created a situation where the remaining physical machines would not
    meet the needs of the virtual machines in the event of a failure.'''

    obj = vim.client.factory.create('{urn:vim25}InsufficientFailoverResourcesFault')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 4:
        raise IndexError('Expected at least 5 arguments got: %d' % len(args))

    required = [ 'dynamicProperty', 'dynamicType', 'faultCause', 'faultMessage' ]
    optional = [  ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

EventFilterSpecRecursionOption = Enum(
    'all',
    'children',
    'self',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def HostConnectSpec(vim, *args, **kwargs):
    '''Specifies the parameters needed to add a single host. This includes a small set
    of optional information about the host configuration. This allows the network
    and datastore configuration of the host to be synchronized with the naming
    conventions of the datacenter, as well as the configuration of a vim account
    (the username/password for the virtual machine files that is created on disk).'''

    obj = vim.client.factory.create('{urn:vim25}HostConnectSpec')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 1:
        raise IndexError('Expected at least 2 arguments got: %d' % len(args))

    required = [ 'force' ]
    optional = [ 'hostName', 'managementIp', 'password', 'port', 'sslThumbprint', 'userName',
        'vimAccountName', 'vimAccountPassword', 'vmFolder', 'dynamicProperty',
        'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def UserInputRequiredParameterMetadata(vim, *args, **kwargs):
    '''The UserInputRequiredParameterMetadata data object represents policy option
    metadata information for configuration data. The Profile Engine saves
    configuration data from the user input options in the host AnswerFile. See the
    ExecuteHostProfile and ApplyHostConfig_Task methods.'''

    obj = vim.client.factory.create('{urn:vim25}UserInputRequiredParameterMetadata')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 1:
        raise IndexError('Expected at least 2 arguments got: %d' % len(args))

    required = [ 'id' ]
    optional = [ 'userInputParameter', 'parameter', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostHardwareElementStatus = Enum(
    'Green',
    'Red',
    'Unknown',
    'Yellow',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def DeviceNotSupported(vim, *args, **kwargs):
    '''The virtual machine uses a device type that is not supported on the host.If
    this fault is returned as a subfault of DisallowedMigrationDeviceAttached, this
    indicates that although this device may be supported on the destination host,
    the hosts do not support the requested migration of the virtual machine while
    using this device.'''

    obj = vim.client.factory.create('{urn:vim25}DeviceNotSupported')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 6:
        raise IndexError('Expected at least 7 arguments got: %d' % len(args))

    required = [ 'device', 'reason', 'dynamicProperty', 'dynamicType', 'faultCause',
        'faultMessage' ]
    optional = [  ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def VirtualMachineCapability(vim, *args, **kwargs):
    '''This data object type contains information about the operation/capabailities of
    a virtual machine'''

    obj = vim.client.factory.create('{urn:vim25}VirtualMachineCapability')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 32:
        raise IndexError('Expected at least 33 arguments got: %d' % len(args))

    required = [ 'bootOptionsSupported', 'bootRetryOptionsSupported', 'changeTrackingSupported',
        'consolePreferencesSupported', 'cpuFeatureMaskSupported',
        'disableSnapshotsSupported', 'diskSharesSupported', 'guestAutoLockSupported',
        'hostBasedReplicationSupported', 'lockSnapshotsSupported',
        'memoryReservationLockSupported', 'memorySnapshotsSupported',
        'multipleCoresPerSocketSupported', 'multipleSnapshotsSupported',
        'npivWwnOnNonRdmVmSupported', 'poweredOffSnapshotsSupported',
        'quiescedSnapshotsSupported', 'recordReplaySupported',
        'revertToSnapshotSupported', 's1AcpiManagementSupported',
        'settingDisplayTopologySupported', 'settingScreenResolutionSupported',
        'settingVideoRamSizeSupported', 'snapshotConfigSupported',
        'snapshotOperationsSupported', 'swapPlacementSupported',
        'toolsAutoUpdateSupported', 'toolsSyncTimeSupported',
        'virtualMmuUsageSupported', 'vmNpivWwnDisableSupported', 'vmNpivWwnSupported',
        'vmNpivWwnUpdateSupported' ]
    optional = [ 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class SystemBootDevice(Base):
    '''
    Display the system boot device
    '''
    moid = 'ha-cli-handler-system-boot-device'
    def get(self):
        '''
        Get the systems boot device.
        :returns: vim.EsxCLI.system.boot.device.get.SystemBootDevice
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.system.boot.device.Get',
                            )   



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DistributedVirtualSwitchPortConnecteeConnecteeType = Enum(
    'hostConsoleVnic',
    'hostVmkVnic',
    'pnic',
    'vmVnic',

)




from infi.pyutils.lazy import cached_method
from pyvisdk.do.traversal_spec import TraversalSpec
from pyvisdk.do.selection_spec import SelectionSpec
from pyvisdk.do.wait_options import WaitOptions
from logging import getLogger
from re import match, findall
from munch import Munch

logger = getLogger(__name__)

INITIAL_VERSION = ''

# foo.bar
# foo.arProp["key val"]
# foo.arProp["key val"].baz
PROPERTY_NAME_PATTERN = r'\w+|\["[^"\]]+"\]'

class CachedPropertyCollector(object):
    """
    Facade for using PropertyCollectors to fetch a list of properties from all instances of a specific object_type

    :param vim: :py:class:`Vim` instance
    :param managedObjectTypeName: A name of managed object type, e.g. HostSystem
    :param propertiesList: A list of properties to fetch, can be nested, e.g. config.storageDevice
    """
    def __init__(self, vim, managedObjectTypeName, propertiesList):
        super(CachedPropertyCollector, self).__init__()
        self._vim = vim
        self._managedObjectTypeName = managedObjectTypeName
        self._propertiesList = propertiesList
        self._version = INITIAL_VERSION
        self._result = {}

    def __repr__(self):
        args = (self.__class__.__name__, getattr(self, '_managedObjectTypeName', None),
                getattr(self, '_propertiesList', []), getattr(self, '_version', repr('')))
        return "<{}: objectType={!r}, properties={!r}, version={}>".format(*args)

    def _guessTraversalSpecName(self, managed_object_type_name, property_name):
        """:returns: A guessable name of a TraversalSpec being used in this facade"""
        name = "{}.{}".format(managed_object_type_name, property_name)
        return name

    def _createTraversalSpec(self, managed_object_type_name, property_name, next_selector_names=[]):
        """:returns: a TravelSpec object whose name is '{managed_object_type_name}.{property_name}'"""
        return TraversalSpec(self._vim, name=self._guessTraversalSpecName(managed_object_type_name, property_name),
                             type=managed_object_type_name, path=property_name,
                             selectSet=[SelectionSpec(self._vim, name=name) for name in next_selector_names])

    @cached_method
    def _getContainerView(self):
        kwargs = dict(container=self._vim.root, type=[self._managedObjectTypeName], recursive=True)
        return self._vim.service_content.viewManager.CreateContainerView(**kwargs)

    @cached_method
    def _getObjectSet(self):
        from pyvisdk.do.object_spec import ObjectSpec
        return ObjectSpec(self._vim, obj=self._getContainerView().ref,
                          selectSet=self._getSelectSet())

    @cached_method
    def _getPropSet(self):
        from pyvisdk.do.property_spec import PropertySpec
        return [PropertySpec(self._vim, type=self._managedObjectTypeName, pathSet=self._propertiesList)]

    @cached_method
    def _getPropertyCollector(self):
        property_collector = self._vim.service_content.propertyCollector.CreatePropertyCollector()
        property_collector.CreateFilter(self._getPropertyFilterSpec(), partialUpdates=True)
        return property_collector

    @cached_method
    def _getPropertyFilterSpec(self):
        # http://vijava.sourceforge.net/vSphereAPIDoc/ver5/ReferenceGuide/vmodl.query.PropertyCollector.FilterSpec.html
        from pyvisdk.do.property_filter_spec import PropertyFilterSpec
        return PropertyFilterSpec(self._vim, propSet=self._getPropSet(),
                                  objectSet=[self._getObjectSet()])

    @cached_method
    def _getSelectSet(self):
        """This method returns a SelectSet that travels the entire heirarchy.
        If you want to go over heirarchy in a more efficient way, overload this method"""
        select_set = list(self._vim._buildFullTraversal())
        select_set.append(self._createTraversalSpec("ContainerView", 'container',
                          [select.name for select in select_set]))
        return select_set

    def _getChanges(self, time_in_seconds=0, truncated_version=None):
        # http://vijava.sourceforge.net/vSphereAPIDoc/ver5/ReferenceGuide/vmodl.query.PropertyCollector.html#waitForUpdatesEx
        from suds import WebFault
        property_collector = self._getPropertyCollector()
        wait_options = WaitOptions(self._vim, maxWaitSeconds=time_in_seconds)
        logger.debug("Checking for updates on property collector {!r}".format(self))
        try:
            update = property_collector.WaitForUpdatesEx(truncated_version or self._version, wait_options)
            logger.debug("There is {} pending update".format('no' if update is None else 'indeed an'))
            return update
        except WebFault, e:
            if e.fault.detail.__keylist__ == ['InvalidCollectorVersionFault']:
                logger.error("caught InvalidCollectorVersionFault, collector version is out of date or invalid")
                self._version = INITIAL_VERSION
                return self._getChanges(time_in_seconds=time_in_seconds, truncated_version=truncated_version)

    def _refToString(self, ref):
        return "{}:{}".format(ref._type, ref.value)

    def _mergeObjectUpdateIntoCache__enter(self, object_ref_key, objectUpdate):
        # Rebuild the properties dict
        properties = {propertyChange.name:propertyChange.val
                      for propertyChange in filter(lambda propertyChange:propertyChange.op in ['add', 'assign'],
                                                   objectUpdate.changeSet)}
        message = "Replacing cache for object_ref_key {} with a dictionary of the following keys {}"
        logger.debug(message.format(object_ref_key, properties.keys()))
        self._result[object_ref_key] = properties

    def _mergeObjectUpdateIntoCache__leave(self, object_ref_key, objectUpdate=None):
        # the object no longer exists, we drop it from the result dictionary
        logger.debug("Removing object_ref_key {} from cache".format(object_ref_key))
        _ = self._result.pop(object_ref_key, None)

    def _split_property_path(self, key):
        return findall(r"[A-Za-z]*\[[^\]]+\]", key)

    def _walk_on_property_path(self, path):
        from re import findall
        matches = [Munch(value=item) for item in findall(PROPERTY_NAME_PATTERN, path)]
        for match in matches:
            if match.value.startswith('['):
                match.type = "key"
                match.value = match.value[2:-2]
            else:
                match.type = "property"
        return matches

    def _get_list_and_object_to_update(self, property_dict, path, value, last=False):
        for key in property_dict.keys():
            if path.startswith(key):
                break
        # key is a prefix of path
        if path == key:
            return property_dict
        object_to_update = property_dict[key]
        path = path.replace(key, '').lstrip('.')
        walks = self._walk_on_property_path(path)
        for item in walks if last else walks[:-1]:
            if item.type == "key":
                object_to_update = [element for element in object_to_update if element.key == item.value][0]
            else:
                if isinstance(object_to_update, (dict, Munch)):
                    object_to_update = object_to_update.get(item.value)
                else:
                    object_to_update = getattr(object_to_update, item.value)
        return object_to_update

    def _get_property_name_to_update(self, property_dict, path):
        for key in property_dict.keys():
            if path == key:
                return key
        return self._walk_on_property_path(path)[-1].value

    def _get_key_to_remove(self, key):
        return self._walk_on_property_path(key)[-1].value

    def _mergePropertyChange__add(self, property_dict, key, value):
        # http://vijava.sourceforge.net/vSphereAPIDoc/ver5/ReferenceGuide/vmodl.query.PropertyCollector.Change.html
        list_to_update = self._get_list_and_object_to_update(property_dict, key, value)
        logger.debug("Appending {}".format(value.__class__))
        list_to_update.insert(-1, value)

    def _mergePropertyChange__assign(self, property_dict, key, value):
        # http://vijava.sourceforge.net/vSphereAPIDoc/ver5/ReferenceGuide/vmodl.query.PropertyCollector.Change.html
        object_to_update = self._get_list_and_object_to_update(property_dict, key, value, key.endswith(']'))
        name = self._get_property_name_to_update(property_dict, key)
        logger.debug("Assigning {} to {}".format(value.__class__, name))
        assignment_method = getattr(object_to_update, "__setitem__", object_to_update.__setattr__)
        assignment_method(name, value)

    def _mergePropertyChange__remove(self, property_dict, key, value):
        # http://vijava.sourceforge.net/vSphereAPIDoc/ver5/ReferenceGuide/vmodl.query.PropertyCollector.Change.html
        list_to_update = self._get_list_and_object_to_update(property_dict, key, value)
        key_to_remove = self._get_key_to_remove(key)
        value_list = [item for item in list_to_update if item.key == key_to_remove]
        if not value_list:
            msg = "No item with key {!r} in list {!r}, original value is {!r}, original key is {!r}"
            logger.warn(msg.format(key_to_remove, list_to_update, value, key))
        else:
            value = value_list[0]
            list_to_update.remove(value)

    def _mergeObjectUpdateIntoCache__modify(self, object_ref_key, objectUpdate):
        # http://vijava.sourceforge.net/vSphereAPIDoc/ver5/ReferenceGuide/vmodl.query.PropertyCollector.ObjectUpdate.html
        # http://vijava.sourceforge.net/vSphereAPIDoc/ver5/ReferenceGuide/vmodl.query.PropertyCollector.Change.html
        # http://vijava.sourceforge.net/vSphereAPIDoc/ver5/ReferenceGuide/vmodl.query.PropertyCollector.MissingProperty.html
        properties = self._result[object_ref_key]
        logger.debug("Modifying cache for object_ref_key {}".format(object_ref_key))
        updatemethods = dict(add=self._mergePropertyChange__add,
                             assign=self._mergePropertyChange__assign,
                             remove=self._mergePropertyChange__remove,
                             indirectRemove=self._mergePropertyChange__remove)
        for propertyChange in objectUpdate.changeSet:
            logger.debug("Modifying property {}, operation {}".format(propertyChange.name, propertyChange.op))
            updatemethods[propertyChange.op](properties, propertyChange.name, propertyChange.val)
        for missingSet in objectUpdate.missingSet:
            logger.debug("Removing from cache a property that has gone missing{}".format(missingSet.path))
            self._mergePropertyChange__remove(properties, missingSet.path, None)

    def _mergeObjectUpdateIntoCache(self, objectUpdate):
        # http://vijava.sourceforge.net/vSphereAPIDoc/ver5/ReferenceGuide/vmodl.query.PropertyCollector.ObjectUpdate.html
        updateMethods = dict(enter=self._mergeObjectUpdateIntoCache__enter,
                             leave=self._mergeObjectUpdateIntoCache__leave,
                             modify=self._mergeObjectUpdateIntoCache__modify)
        object_ref_key = self._refToString(objectUpdate.obj.ref)
        logger.debug("Update kind {} on cache key {}".format(objectUpdate.kind, object_ref_key))
        updateMethods[objectUpdate.kind](object_ref_key, objectUpdate)

    def _mergeChangesIntoCache(self, update):
        # http://vijava.sourceforge.net/vSphereAPIDoc/ver5/ReferenceGuide/vmodl.query.PropertyCollector.UpdateSet.html
        # http://vijava.sourceforge.net/vSphereAPIDoc/ver5/ReferenceGuide/vmodl.query.PropertyCollector.FilterUpdate.html
        logger.debug("Merging changes into cache; the following log messages contain the current cache and the incoming update")
        logger.debug(repr(self._result))
        logger.debug(repr(update))
        for filterSet in update.filterSet:
            for key in map(lambda missingObject: self._refToString(missingObject.obj), filterSet.missingSet):
                logger.debug("Removing key {} from cache because it is missing in the filterSet".format(key))
                _ = self._result.pop(key, None)
            for objectUpdate in filterSet.objectSet:
                self._mergeObjectUpdateIntoCache(objectUpdate)
        if update.truncated:
            self._mergeChangesIntoCache(self._getChanges(0, update.version))
        else:
            self._version = update.version
            logger.debug("Cache of {!r} is updated for version {}".format(self, self._version))
            logger.debug("Updated cached after merge follows")
            logger.debug(repr(self._result))


    def checkForUpdates(self):
        """:returns: True if the cached data is not up to date"""
        return self.waitForUpdates(0)

    def getProperties(self):
        """This method checks first if there are changes in the server.
        If there are, the changes are merged into the cache and then returned from the cache.
        If there are not, the data is returned from the cache.
        :rtype: a dictionary with MoRefs as keys, and propertyName=propertyValue dictionary as values"""

        update = self._getChanges()
        if update is not None:
            self._mergeChangesIntoCache(update)
        return self.getPropertiesFromCache()

    def getPropertiesFromCache(self):
        """:returns: the cached properties immediately from the cache.
        :rtype: a dictionary with MoRefs as keys, and propertyName=propertyValue dictionary as values"""
        return self._result

    def waitForUpdates(self, time_in_seconds):
        """This method is blocking a maximum time of time_in_seconds, depending if there are changes on the server.
        This method does not update the cache with the changes, if there are any.
        :returns: True if there are updates on the server, False if there are not."""
        update = self._getChanges(time_in_seconds)
        return update is not None

class HostSystemCachedPropertyCollector(CachedPropertyCollector):
    """
    Facade for fetching host attributes by using a faster traversal (e.g no need to traverse inside HostSystem)
    """

    def __init__(self, vim, hostProperties):
        super(HostSystemCachedPropertyCollector, self).__init__(vim, 'HostSystem', hostProperties)

    @cached_method
    def _getSelectSet(self):
        #TODO docstring
        select_set = list()
        select_set.append(self._createTraversalSpec("ClusterComputeResource", 'host'))
        select_set.append(self._createTraversalSpec("ComputeResource", 'host'))
        select_set.append(self._createTraversalSpec("Datacenter", 'hostFolder',
                          ['Folder.childEntity']))
        select_set.append(self._createTraversalSpec("Folder", 'childEntity',
                          ['Datacenter.hostFolder', 'ClusterComputeResource.host', 'ComputeResource.host']))
        select_set.append(self._createTraversalSpec("ContainerView", 'container',
                          [select.name for select in select_set]))
        return select_set


class VirtualMachinePropertyCollector(CachedPropertyCollector):
    def __init__(self, vim, properties):
        super(VirtualMachinePropertyCollector, self).__init__(vim, 'VirtualMachine', properties)

    @cached_method
    def _getSelectSet(self):
        select_set = list()
        select_set.append(self._createTraversalSpec("Datacenter", 'vmFolder',
                                                    ["Folder.childEntity"]))
        select_set.append(self._createTraversalSpec("Folder", 'childEntity',
                                                    ['Datacenter.vmFolder', "Folder.childEntity"]))
        select_set.append(self._createTraversalSpec("ContainerView", 'container',
                          [select.name for select in select_set]))
        return select_set





from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class StorageNmpPath(Base):
    '''
    Operations pertaining to the paths currently claimed by the VMware Native Multipath Plugin.
    '''
    moid = 'ha-cli-handler-storage-nmp-path'
    def list(self, device=None, path=None):
        '''
        List the paths currently claimed by the VMware NMP Multipath Plugin and show the SATP and PSP information associated with that path.
        :param device: string, Filter the output of this command to only show paths to a single device.
        :param path: string, Filter the output of this command to only show a single path.
        :returns: vim.EsxCLI.storage.nmp.path.list.ScsiPath[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.nmp.path.List',
                            device=device,
                            path=path,
                            )   



from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class SystemSyslogConfig(Base):
    '''
    Operations relating to system logging configuration
    '''
    moid = 'ha-cli-handler-system-syslog-config'
    def set(self, defaultrotate=None, defaultsize=None, logdir=None, logdirunique=None, loghost=None, reset=None):
        '''
        Set global log configuration options
        :param defaultrotate: long, Default number of rotated logs to keep
        :param defaultsize: long, Default size of logs before rotation, in KiB
        :param logdir: string, The directory to output logs to
        :param logdirunique: boolean, Place logs in a unique subdirectory of logdir, based on hostname
        :param loghost: string, The remote host to output logs to
        :param reset: string, Reset values to default
        :returns: boolean
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.system.syslog.config.Set',
                            defaultrotate=defaultrotate,
                            defaultsize=defaultsize,
                            logdir=logdir,
                            logdirunique=logdirunique,
                            loghost=loghost,
                            reset=reset,
                            )
    def get(self):
        '''
        Show the current global configuration values
        :returns: vim.EsxCLI.system.syslog.config.get.SyslogConfiguration
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.system.syslog.config.Get',
                            )   



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def HostVirtualSwitchBeaconConfig(vim, *args, **kwargs):
    '''This data object type describes the configuration of the beacon to probe
    connectivity of physical network adapters. A beacon is sent out of one network
    adapter and should arrive on another network adapter in the team. The
    successful roundtrip indicates that the network adapters are working.Define
    this data object to enable beacon probing as a method to validate the link
    status of a physical network adapter. Beacon probing must be configured in
    order to use the beacon status as a criteria to determine if a physical network
    adapter failed.See checkBeacon'''

    obj = vim.client.factory.create('{urn:vim25}HostVirtualSwitchBeaconConfig')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 1:
        raise IndexError('Expected at least 2 arguments got: %d' % len(args))

    required = [ 'interval' ]
    optional = [ 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineDeviceRuntimeInfoVirtualEthernetCardRuntimeStateVmDirectPathGen2InactiveReasonOther = Enum(
    'vmNptIncompatibleHost',
    'vmNptIncompatibleNetwork',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def ClusterDasAamHostInfo(vim, *args, **kwargs):
    '''The ClusterDasAamHostInfo object contains a list of the ESX hosts in an HA
    cluster and a list that identifies the hosts. (AAM is a component of the HA
    service.) The primary hosts share the joint responsibility of maintaining all
    cluster state and one will initiate failover actions should a failure
    occur.When you add an ESX host to a vSphere HA cluster, the host downloads HA
    agent components from the vCenter Server. The HA agent maintains communication
    with the vCenter Server.When the host downloads the HA agent, the host
    configures the agent to communicate with other agents in the cluster. A host
    that joins the cluster communicates with an existing primary host to complete
    its configuration (except when you are adding the first host to the
    cluster).One of the primary hosts assumes the role of the active primary host.
    The active primary host responsibilities include the following activities:If
    the active primary host fails, another primary host replaces it.'''

    obj = vim.client.factory.create('{urn:vim25}ClusterDasAamHostInfo')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 0:
        raise IndexError('Expected at least 1 arguments got: %d' % len(args))

    required = [  ]
    optional = [ 'hostDasState', 'primaryHosts', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineRelocateTransformation = Enum(
    'flat',
    'sparse',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VmDasBeingResetEventReasonCode = Enum(
    'appHeartbeatFailure',
    'vmtoolsHeartbeatFailure',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def PhysicalNicLinkInfo(vim, *args, **kwargs):
    '''The PhysicalNicLinkInfo data object describes the link speed and the type of
    duplex communication. The link speed indicates the bit rate in megabits per
    second. The duplex boolean indicates if the link is capable of full-duplex or
    half-duplex communication.'''

    obj = vim.client.factory.create('{urn:vim25}PhysicalNicLinkInfo')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 2:
        raise IndexError('Expected at least 3 arguments got: %d' % len(args))

    required = [ 'duplex', 'speedMb' ]
    optional = [ 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.base.base_entity import BaseEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class Profile(BaseEntity):
    '''The managed object is the base class for host and cluster profiles.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.Profile):
        super(Profile, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def complianceStatus(self):
        '''Overall compliance of entities associated with this profile. If one of the
        entities is out of compliance, the profile is'''
        return self.update('complianceStatus')
    @property
    def config(self):
        '''Configuration data for the profile.'''
        return self.update('config')
    @property
    def createdTime(self):
        '''Time at which the profile was created.'''
        return self.update('createdTime')
    @property
    def description(self):
        '''Localizable description of the profile'''
        return self.update('description')
    @property
    def entity(self):
        '''List of managed entities associated with the profile.'''
        return self.update('entity')
    @property
    def modifiedTime(self):
        '''Time at which the profile was last modified.'''
        return self.update('modifiedTime')
    @property
    def name(self):
        '''Name of the profile.'''
        return self.update('name')

    
    
    def AssociateProfile(self, entity):
        '''Associate a profile with a managed entity. You can check the compliance of
        entities associated with a profile by calling the CheckProfileCompliance_Task
        method.
        
        :param entity: The entity(s) to associate with the profile. If an entity is already associated with the profile, the association is maintained and the vCenter Server does not perform any action.
        
        '''
        return self.delegate("AssociateProfile")(entity)
    
    def CheckProfileCompliance_Task(self, entity=None):
        '''Check compliance of an entity against a Profile.
        
        :param entity: If specified, the compliance check is performed on this entity. If the entity is not specified, the vCenter Server runs a compliance check on all the entities associated with the profile. The entity does not have to be associated with the profile.
        
        '''
        return self.delegate("CheckProfileCompliance_Task")(entity)
    
    def DestroyProfile(self):
        '''Destroy the profile.
        
        '''
        return self.delegate("DestroyProfile")()
    
    def DissociateProfile(self, entity=None):
        '''Remove the association between a profile and a managed entity.
        
        :param entity: List of entities. The vCenter Server will remove the associations that the profile has with the entities in the list. If unset, the Server removes all the associations that the profile has with any managed entities in the inventory. If the specified entity is not associated with the profile, the Server does not perform any action.
        
        '''
        return self.delegate("DissociateProfile")(entity)
    
    def ExportProfile(self):
        '''Export the profile in a serialized form. To use the serialized string to create
        a profile, specify a ProfileSerializedCreateSpec when you call the
        HostProfileManager.CreateProfile method.
        
        '''
        return self.delegate("ExportProfile")()
    
    def RetrieveDescription(self):
        '''Returns the localizable description for the profile.
        
        '''
        return self.delegate("RetrieveDescription")()



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def MonthlyByWeekdayTaskScheduler(vim, *args, **kwargs):
    '''The MonthlyByWeekdayTaskScheduler data object sets the time for monthly task
    execution. You identify a single day for task execution by specifying the week
    of the month and day of the week, and you complete the schedule by setting the
    inherited properties for the hour and minute.By default, the scheduler executes
    the task on the specified day every month. If you set the interval to a value
    greater than 1, the task will execute at the specified monthly interval. (For
    example, an interval of 2 will cause the task to execute on the specified day,
    hour, and minute every 2 months.)'''

    obj = vim.client.factory.create('{urn:vim25}MonthlyByWeekdayTaskScheduler')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 5:
        raise IndexError('Expected at least 6 arguments got: %d' % len(args))

    required = [ 'offset', 'weekday', 'hour', 'minute', 'interval' ]
    optional = [ 'activeTime', 'expireTime', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class StorageNmpPsp(Base):
    '''
    Operations pertaining to the Path Selection Policy Plugins for the VMware Native Multipath Plugin.
    '''
    moid = 'ha-cli-handler-storage-nmp-psp'
    def list(self):
        '''
        List the Path Selection Plugins (PSP) that are currently loaded into the NMP system and display information about those PSPs
        :returns: vim.EsxCLI.storage.nmp.psp.list.PathSelectionPolicy[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.nmp.psp.List',
                            )   



from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.folder import Folder

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class StoragePod(Folder):
    '''The StoragePod data object aggregates the storage resources of associated
    Datastore objects into a single storage resource for use by virtual machines.
    The storage services such as Storage DRS (Distributed Resource Scheduling),
    enhance the utility of the storage pod.Use the Folder.CreateStoragePod method
    to create an instance of this object.NOTE: This managed object type and all of
    its methods are experimental and subject to change in future releases.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.StoragePod):
        super(StoragePod, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def podStorageDrsEntry(self):
        '''Storage DRS related attributes of the Storage Pod.'''
        return self.update('podStorageDrsEntry')
    @property
    def summary(self):
        '''Storage pod summary.'''
        return self.update('summary')

    



from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class StorageNfs(Base):
    '''
    Operations to create, manage and remove Network Attached Storage filesystems.
    '''
    moid = 'ha-cli-handler-storage-nfs'
    def add(self, host, share, volumename, readonly=None):
        '''
        Add a new NAS volume to the ESX Host and mount it with the given volume name.
        :param host: string, The hostname or IP address of the NAS volume to add and mount on the system.
        :param readonly: boolean, If set this flag will set the mount point to be read-only.
        :param share: string, The share name on the remote system to use for this NAS mount point.
        :param volumename: string, The volume name to use for the NAS mount.  This must be a unique volume name and cannot conflict with existing NAS, VMFS or other volume names.
        :returns: boolean
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.nfs.Add',
                            host=host,
                            readonly=readonly,
                            share=share,
                            volumename=volumename,
                            )
    def list(self):
        '''
        List the NAS volumes currently known to the ESX host.
        :returns: vim.EsxCLI.storage.nfs.list.NasMount[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.nfs.List',
                            )
    def remove(self, volumename):
        '''
        Remove an existing NAS volume from the ESX host.
        :param volumename: string, The volume name of the NAS volume to remove from the ESX host.
        :returns: boolean
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.nfs.Remove',
                            volumename=volumename,
                            )   



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def VirtualMachineQuickStats(vim, *args, **kwargs):
    '''A set of statistics that are typically updated with near real-time regularity.
    This data object type does not support notification, for scalability reasons.
    Therefore, changes in QuickStats do not generate property collector updates. To
    monitor statistics values, use the statistics and alarms modules instead.'''

    obj = vim.client.factory.create('{urn:vim25}VirtualMachineQuickStats')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 1:
        raise IndexError('Expected at least 2 arguments got: %d' % len(args))

    required = [ 'guestHeartbeatStatus' ]
    optional = [ 'balloonedMemory', 'compressedMemory', 'consumedOverheadMemory',
        'distributedCpuEntitlement', 'distributedMemoryEntitlement', 'ftLatencyStatus',
        'ftLogBandwidth', 'ftSecondaryLatency', 'guestMemoryUsage', 'hostMemoryUsage',
        'overallCpuDemand', 'overallCpuUsage', 'privateMemory', 'sharedMemory',
        'ssdSwappedMemory', 'staticCpuEntitlement', 'staticMemoryEntitlement',
        'swappedMemory', 'uptimeSeconds', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def SSLVerifyFault(vim, *args, **kwargs):
    '''SSLVerifyFault is thrown by the host connect method if the VC server could not
    verify the authenticity of the host's SSL certificate. Currently, we do not
    distinguish the various possible reasons why the certificate could not be
    verified because we don't provide a way for the user to overwrite these reasons
    other than turning off SSL certificate verification completely. The only
    exception is the case when the certificate was rejected because it was self-
    signed. This is the most likely case when the user may want to overwrite the
    behavior by specifying the certificate's thumbprint in the ConnectSpec the next
    time the user connects to the host.'''

    obj = vim.client.factory.create('{urn:vim25}SSLVerifyFault')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 6:
        raise IndexError('Expected at least 7 arguments got: %d' % len(args))

    required = [ 'selfSigned', 'thumbprint', 'dynamicProperty', 'dynamicType', 'faultCause',
        'faultMessage' ]
    optional = [  ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostPatchManagerInstallState = Enum(
    'hostRestarted',
    'imageActive',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostNumericSensorType = Enum(
    'fan',
    'other',
    'power',
    'temperature',
    'voltage',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualDiskType = Enum(
    'eagerZeroedThick',
    'flatMonolithic',
    'preallocated',
    'raw',
    'rdm',
    'rdmp',
    'sparse2Gb',
    'sparseMonolithic',
    'thick',
    'thick2Gb',
    'thin',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def MonthlyByDayTaskScheduler(vim, *args, **kwargs):
    '''The MonthlyByDayTaskScheduler data object sets the time for monthly task
    execution. You can set the schedule for task execution on one day during the
    month, and you complete the schedule by setting the inherited properties for
    the hour and minute.By default the scheduler executes the task on the specified
    day every month. If you set the interval to a value greater than 1, the task
    will execute at the specified monthly interval. (For example, an interval of 2
    will cause the task to execute on the specified day, hour, and minute every 2
    months.)'''

    obj = vim.client.factory.create('{urn:vim25}MonthlyByDayTaskScheduler')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 4:
        raise IndexError('Expected at least 5 arguments got: %d' % len(args))

    required = [ 'day', 'hour', 'minute', 'interval' ]
    optional = [ 'activeTime', 'expireTime', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

FileSystemMountInfoVStorageSupportStatus = Enum(
    'vStorageSupported',
    'vStorageUnknown',
    'vStorageUnsupported',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

AutoStartWaitHeartbeatSetting = Enum(
    'no',
    'systemDefault',
    'yes',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DiagnosticPartitionStorageType = Enum(
    'directAttached',
    'networkAttached',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineRecordReplayState = Enum(
    'inactive',
    'recording',
    'replaying',

)




from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class NetworkVswitchDvsVmware(Base):
    '''
    Commands to retrieve VMware vSphere Distributed Switch information
    '''
    moid = 'ha-cli-handler-network-vswitch-dvs-vmware'
    def list(self, vdsname=None):
        '''
        List the VMware vSphere Distributed Switch currently configured on the ESXi host.
        :param vdsname: string, Limit the output of this command to only vDS with the given name.
        :returns: vim.EsxCLI.network.vswitch.dvs.vmware.list.VDS[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.network.vswitch.dvs.vmware.List',
                            vdsname=vdsname,
                            )   



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def HostMultipathInfoPath(vim, *args, **kwargs):
    '''The HostMultipathInfoPath data object is a storage entity that represents a
    topological path from a host bus adapter to a SCSI logical unit. Each path is
    unique although each host bus adapter/SCSI logical unit pair can have multiple
    paths.Path objects are identified by a key. The specifics of how the key is
    formatted are dependent on the implementation. Example implementations include
    using strings like "vmhba1:0:0:0".'''

    obj = vim.client.factory.create('{urn:vim25}HostMultipathInfoPath')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 5:
        raise IndexError('Expected at least 6 arguments got: %d' % len(args))

    required = [ 'adapter', 'key', 'lun', 'name', 'pathState' ]
    optional = [ 'isWorkingPath', 'state', 'transport', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def HostDiskDimensionsChs(vim, *args, **kwargs):
    '''This data object type describes dimensions using the cylinder, head, sector
    (CHS) coordinate system. This coordinate system is generally needed for
    partitioning for legacy reasons. When defining partitions, many partitioning
    utilities do not function correctly when certain CHS constraints are not met.'''

    obj = vim.client.factory.create('{urn:vim25}HostDiskDimensionsChs')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 3:
        raise IndexError('Expected at least 4 arguments got: %d' % len(args))

    required = [ 'cylinder', 'head', 'sector' ]
    optional = [ 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def NotEnoughCpus(vim, *args, **kwargs):
    '''The host hardware does not have enough CPU cores to support the number of
    virtual CPUs in the virtual machine.If the host is using hyperthreading,
    NotEnoughLogicalCpus is employed instead of NotEnoughCpus.'''

    obj = vim.client.factory.create('{urn:vim25}NotEnoughCpus')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 6:
        raise IndexError('Expected at least 7 arguments got: %d' % len(args))

    required = [ 'numCpuDest', 'numCpuVm', 'dynamicProperty', 'dynamicType', 'faultCause',
        'faultMessage' ]
    optional = [  ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def CustomizationGuiRunOnce(vim, *args, **kwargs):
    '''The commands listed in the GuiRunOnce data object type are executed when a user
    logs on the first time after customization completes. The logon may be driven
    by the AutoLogon setting.The GuiRunOnce data object type maps to the GuiRunOnce
    key in the answer file. These values are transferred into the file that
    VirtualCenter stores on the target virtual disk. For more detailed information,
    see the document .'''

    obj = vim.client.factory.create('{urn:vim25}CustomizationGuiRunOnce')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 1:
        raise IndexError('Expected at least 2 arguments got: %d' % len(args))

    required = [ 'commandList' ]
    optional = [ 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class StorageCoreClaimrule(Base):
    '''
    Operations pertaining to the pluggable storage architecture claiming rule system. These operations operate on the rules used to determine the PSA plugin used to claim storage paths.
    '''
    moid = 'ha-cli-handler-storage-core-claimrule'
    def load(self, claimruleclass=None):
        '''
        Load path claiming rules from config file into the VMkernel.
        :param claimruleclass: string, Indicate the claim rule class to use in this operation [MP, Filter, VAAI, all].
        :returns: void
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.core.claimrule.Load',
                            claimruleclass=claimruleclass,
                            )
    def convert(self, commit=None):
        '''
        Convert ESX 3.x style /adv/Disk/MaskLUNs LUN masks to Claim Rule format.
WARNING: This conversion will not work for all input MaskLUNs variations! Please inspect the list of generated claim rules carefuly, then if the suggested LUN mask claim rules are correct use the --commit parameter to write the list to the config file.
        :param commit: boolean, Force LUN mask config changes to be saved. If this parameter is omitted, config file changes will not be saved.
        :returns: vim.EsxCLI.storage.core.claimrule.convert.ConvertedClaimRule[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.core.claimrule.Convert',
                            commit=commit,
                            )
    def run(self, adapter=None, channel=None, claimruleclass=None, device=None, lun=None, path=None, target=None, type=None, wait=None):
        '''
        Execute path claiming rules.
        :param adapter: string, If the --type parameter is 'location' this value indicates the name of the host bus adapter for the paths you wish to run claim rules on. This parameter can be omitted to indicate claim rules should be run on paths from all adapters.
        :param channel: long, If the --type parameter is 'location' this value indicates the value of the SCSI channel number for the paths you wish to run claim rules on. This parameter can be omitted to indicate claim rules should be run on paths with any channel number.
        :param claimruleclass: string, Indicate the claim rule class to use in this operation [MP, Filter].
        :param device: string, Indicate the Device Uid to use for this operation.
        :param lun: long, If the --type paramter is 'location' this value indicates the value of the SCSI Logical Unit Number (LUN) for the paths you wish to run claim rules on. This parameter can be omitted to indicate claim rules should be run on paths with any Logical Unit Number.
        :param path: string, If the --type paramter is 'path' this value indicates the unique path identifier (UID) or the runtime name of a path which you wish to run claim rules on.
        :param target: long, If the --type parameter is 'location' this value indicates the value of the SCSI target number for the paths you wish to run claim rules on. This parameter can be omitted to indicate claim rules should be run on paths with any target number.
        :param type: string, Indicate the type of claim run you wish to perform. By default the value of 'all' will be used indicating you wish to run claim rules without restricting the run to specific paths or SCSI addresses. Valid values for this parameter are  [location, path, device, all]
        :param wait: boolean, If the --wait flag is provided then the claim command will wait until device registration has completed to return. This option is only valid when used with the --all option.
        :returns: void
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.core.claimrule.Run',
                            adapter=adapter,
                            channel=channel,
                            claimruleclass=claimruleclass,
                            device=device,
                            lun=lun,
                            path=path,
                            target=target,
                            type=type,
                            wait=wait,
                            )
    def move(self, newrule, rule, claimruleclass=None):
        '''
        Move a claimrule from one rule id to another
        :param claimruleclass: string, Indicate the claim rule class to use in this operation [MP, Filter, VAAI].
        :param newrule: long, Indicate the new rule id you wish to apply to the rule given by the --rule parameter.
        :param rule: long, Indicate the rule ID to use for this operation.
        :returns: void
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.core.claimrule.Move',
                            claimruleclass=claimruleclass,
                            newrule=newrule,
                            rule=rule,
                            )
    def list(self, claimruleclass=None):
        '''
        List all the claimrules on the system.
        :param claimruleclass: string, Indicate the claim rule class to use in this operation [MP, Filter, VAAI, all].
        :returns: vim.EsxCLI.storage.core.claimrule.list.PSAClaimRule[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.core.claimrule.List',
                            claimruleclass=claimruleclass,
                            )
    def remove(self, claimruleclass=None, plugin=None, rule=None):
        '''
        Delete a claimrule to the set of claimrules on the system.
        :param claimruleclass: string, Indicate the claim rule class to use in this operation [MP, Filter, VAAI].
        :param plugin: string, Indicate the plugin to use for this operation.
        :param rule: long, Indicate the rule ID to use for this operation.
        :returns: void
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.core.claimrule.Remove',
                            claimruleclass=claimruleclass,
                            plugin=plugin,
                            rule=rule,
                            )
    def add(self, plugin, type, adapter=None, autoassign=None, channel=None, claimruleclass=None, device=None, driver=None, force=None, ifunset=None, iqn=None, lun=None, model=None, rule=None, target=None, transport=None, vendor=None, wwnn=None, wwpn=None):
        '''
        Add a claimrule to the set of claimrules on the system.
        :param adapter: string, Indicate the adapter of the paths to use in this operation.
        :param autoassign: boolean, The system will auto assign a rule id.
        :param channel: long, Indicate the channel of the paths to use in this operation.
        :param claimruleclass: string, Indicate the claim rule class to use in this operation [MP, Filter, VAAI].
        :param device: string, Indicate the Device Uid to use for this operation.
        :param driver: string, Indicate the driver of the paths to use in this operation.
        :param force: boolean, Force claim rules to ignore validity checks and install the rule anyway.
        :param ifunset: string, Execute this command if this advanced user variable is not set to 1
        :param iqn: string, Indicate the iSCSI Qualified Name for the target to use in this operation.
        :param lun: long, Indicate the LUN of the paths to use in this operation.
        :param model: string, Indicate the model of the paths to use in this operation.
        :param plugin: string, Indicate which PSA plugin to use for this operation.
        :param rule: long, Indicate the rule ID to use for this operation.
        :param target: long, Indicate the target of the paths to use in this operation.
        :param transport: string, Indicate the transport of the paths to use in this operation.  Valid Values are:  [block, fc, iscsi, iscsivendor, ide, sas, sata, usb, parallel, unknown]
        :param type: string, Indicate which type of matching used for claim/unclaim or claimrule. Valid values are:  [vendor, location, driver, transport, device, target]
        :param vendor: string, Indicate the vendor of the paths to user in this operation.
        :param wwnn: string, Indicate the World-Wide Node Number for the target to use in this operation.
        :param wwpn: string, Indicate the World-Wide Port Number for the target to use in this operation.
        :returns: void
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.core.claimrule.Add',
                            adapter=adapter,
                            autoassign=autoassign,
                            channel=channel,
                            claimruleclass=claimruleclass,
                            device=device,
                            driver=driver,
                            force=force,
                            ifunset=ifunset,
                            iqn=iqn,
                            lun=lun,
                            model=model,
                            plugin=plugin,
                            rule=rule,
                            target=target,
                            transport=transport,
                            type=type,
                            vendor=vendor,
                            wwnn=wwnn,
                            wwpn=wwpn,
                            )   



from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.view import View

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class ManagedObjectView(View):
    '''ManagedObjectView is the base class for view objects that provide access to a
    set of ManagedEntity objects. ManagedObjectView defines a view list; the list
    contains references to objects in the view. To create a view use the
    ViewManager methods.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.ManagedObjectView):
        super(ManagedObjectView, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def view(self):
        '''The list of references to objects mapped by this view.'''
        return self.update('view')

    



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ClusterDasVmSettingsIsolationResponse = Enum(
    'clusterIsolationResponse',
    'none',
    'powerOff',
    'shutdown',

)




from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class NetworkVswitchStandardPortgroupPolicySecurity(Base):
    '''
    Commands to manipulate security policy setting for the given portgroup.
    '''
    moid = 'ha-cli-handler-network-vswitch-standard-portgroup-policy-security'
    def set(self, portgroupname, allowforgedtransmits=None, allowmacchange=None, allowpromiscuous=None, usevswitch=None):
        '''
        Set the security policy for a given port group
        :param allowforgedtransmits: boolean, Allow ports on the virtual switch to send packets with forged source information.
        :param allowmacchange: boolean, Allow ports on the virtual switch to change their MAC address.
        :param allowpromiscuous: boolean, Allow ports on the virtual switch to enter promiscuous mode.
        :param portgroupname: string, The name of the port group to set security policy for.
        :param usevswitch: boolean, Reset all values for this policy to use parent virtual switch's settings instead of overriding the settings for the port group.   Using this in conjunction with other settings will first reset all of the fields to use the virtual switch setting and then apply the other options after the reset.
        :returns: boolean
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.network.vswitch.standard.portgroup.policy.security.Set',
                            allowforgedtransmits=allowforgedtransmits,
                            allowmacchange=allowmacchange,
                            allowpromiscuous=allowpromiscuous,
                            portgroupname=portgroupname,
                            usevswitch=usevswitch,
                            )
    def get(self, portgroupname):
        '''
        Get the Security Policy governing the given port group. 
        :param portgroupname: string, The name of the port group to use when fetching the network security policy.
        :returns: vim.EsxCLI.network.vswitch.standard.portgroup.policy.security.get.PortGroupSecurityPolicy
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.network.vswitch.standard.portgroup.policy.security.Get',
                            portgroupname=portgroupname,
                            )   



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def HostConfigInfo(vim, *args, **kwargs):
    '''This data object type encapsulates a typical set of host configuration
    information that is useful for displaying and configuring a host.VirtualCenter
    can retrieve this set of information very efficiently even for a large set of
    hosts.'''

    obj = vim.client.factory.create('{urn:vim25}HostConfigInfo')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 2:
        raise IndexError('Expected at least 3 arguments got: %d' % len(args))

    required = [ 'host', 'product' ]
    optional = [ 'activeDiagnosticPartition', 'adminDisabled', 'authenticationManagerInfo',
        'autoStart', 'cacheConfigurationInfo', 'capabilities', 'certificate',
        'consoleReservation', 'datastoreCapabilities', 'datastorePrincipal',
        'dateTimeInfo', 'featureVersion', 'fileSystemVolume', 'firewall', 'flags',
        'hyperThread', 'ipmi', 'localSwapDatastore', 'multipathState', 'network',
        'offloadCapabilities', 'option', 'optionDef', 'pciPassthruInfo',
        'powerSystemCapability', 'powerSystemInfo', 'service', 'sslThumbprintData',
        'sslThumbprintInfo', 'storageDevice', 'systemFile', 'systemResources',
        'virtualMachineReservation', 'virtualNicManagerInfo', 'vmotion',
        'wakeOnLanCapable', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

LinkDiscoveryProtocolConfigProtocolType = Enum(
    'cdp',
    'lldp',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

FibreChannelPortType = Enum(
    'fabric',
    'loop',
    'pointToPoint',
    'unknown',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def HostNumaNode(vim, *args, **kwargs):
    '''Information about a single NUMA node.NOTE: This data object is not modeled
    correctly if the NUMA node contains multiple disjoint memory ranges. If there
    are multiple memory ranges, the client will see one memory ranges from this
    NumaNode object, and the memory range may or may not belong to this NUMA node.'''

    obj = vim.client.factory.create('{urn:vim25}HostNumaNode')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 4:
        raise IndexError('Expected at least 5 arguments got: %d' % len(args))

    required = [ 'cpuID', 'memoryRangeBegin', 'memoryRangeLength', 'typeId' ]
    optional = [ 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostProfileManagerAnswerFileStatus = Enum(
    'invalid',
    'unknown',
    'valid',

)




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.base.base_entity import BaseEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class OptionManager(BaseEntity):
    '''This managed object type is used for managing key/value pair options.* You can
    define options on the fly, in a logical tree using a dot notation for keys. For
    example, "Ethernet.Connection" describes the Connection option as child of the
    Ethernet option. * You can use the queryMethod to retrieve a single property or
    a subset of properties based on the dot notation path.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.OptionManager):
        super(OptionManager, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def setting(self):
        '''A list of the current settings for the key/value pair options.'''
        return self.update('setting')
    @property
    def supportedOption(self):
        '''A list of supported key/value pair options including their type information.'''
        return self.update('supportedOption')

    
    
    def QueryOptions(self, name=None):
        '''Returns a specific node or nodes in the option hierarchy.Returns a specific
        node or nodes in the option hierarchy.Returns a specific node or nodes in the
        option hierarchy.
        
        :param name: 
        
        '''
        return self.delegate("QueryOptions")(name)
    
    def UpdateOptions(self, changedValue):
        '''Updates one or more properties. These properties are changed atomically: either
        all are applied or none are.Updates one or more properties. These properties
        are changed atomically: either all are applied or none are.Updates one or more
        properties. These properties are changed atomically: either all are applied or
        none are.Updates one or more properties. These properties are changed
        atomically: either all are applied or none are.
        
        :param changedValue: 
        
        '''
        return self.delegate("UpdateOptions")(changedValue)



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DiagnosticManagerLogCreator = Enum(
    'hostd',
    'install',
    'recordLog',
    'serverd',
    'vpxa',
    'vpxClient',
    'vpxd',

)




from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class IscsiIbftboot(Base):
    '''
    Operations that can be performed on iSCSI IBFT boot table
    '''
    moid = 'ha-cli-handler-iscsi-ibftboot'
    def import_(self):
        '''
        Import iSCSI target configuration from iBFT to ESX iSCSI initiators. The boot target recorded in iBFT is added to all the eligible 'dependent' iSCSI adapters.
        :returns: void
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.iscsi.ibftboot.Import',
                            )
    def get(self):
        '''
        Get iSCSI IBFT Boot details.
        :returns: vim.EsxCLI.iscsi.ibftboot.get.IbftBoot[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.iscsi.ibftboot.Get',
                            )




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def HostMultipathStateInfo(vim, *args, **kwargs):
    '''This data object type describes the state of storage paths on the host. All
    storage paths on the host are enumerated in this data object.The reason all
    path state information is encapsulated in this data object is because the path
    may actively change. This data object ensures that a request to gather path
    state changes only needs to fetch this data object.'''

    obj = vim.client.factory.create('{urn:vim25}HostMultipathStateInfo')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 0:
        raise IndexError('Expected at least 1 arguments got: %d' % len(args))

    required = [  ]
    optional = [ 'path', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

FilterSpecLogicalOperator = Enum(
    'logicalAnd',
    'logicalOr',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostFirewallRuleDirection = Enum(
    'inbound',
    'outbound',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def HostVmciAccessManagerAccessSpec(vim, *args, **kwargs):
    '''The AccessSpec data object declares an update to the service access granted to
    a VM. The given list of services will either be granted in addition to existing
    services, replace the existing service or be revoked depending on the mode
    specified. In case of a revoke, an empty or non-existing service list indicates
    that all granted services should be revoked.'''

    obj = vim.client.factory.create('{urn:vim25}HostVmciAccessManagerAccessSpec')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 2:
        raise IndexError('Expected at least 3 arguments got: %d' % len(args))

    required = [ 'mode', 'vm' ]
    optional = [ 'services', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.base.base_entity import BaseEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class HostKernelModuleSystem(BaseEntity):
    '''The KernelModuleSystem managed object controls the configuration of kernel
    modules on the host.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.HostKernelModuleSystem):
        super(HostKernelModuleSystem, self).__init__(core, name=name, ref=ref, type=type)

    

    
    
    def QueryConfiguredModuleOptionString(self, name):
        '''Query the options configured to be passed to the kernel module when loaded.
        Note that this is not necessarily the option string currently in use by the
        kernel module.
        
        :param name: Module name.
        
        '''
        return self.delegate("QueryConfiguredModuleOptionString")(name)
    
    def QueryModules(self):
        '''Query the set of modules on the host.
        
        '''
        return self.delegate("QueryModules")()
    
    def UpdateModuleOptionString(self, name, options):
        '''Specifies the options to be passed to the kernel module when loaded.
        
        :param name: Module name.
        
        :param options: Option string to be passed to the kernel module at load time.
        
        '''
        return self.delegate("UpdateModuleOptionString")(name, options)



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DrsBehavior = Enum(
    'fullyAutomated',
    'manual',
    'partiallyAutomated',

)




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.base.base_entity import BaseEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class AlarmManager(BaseEntity):
    '''The alarm manager is a singleton object for managing alarms within a service
    instance.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.AlarmManager):
        super(AlarmManager, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def defaultExpression(self):
        '''The default setting for each alarm expression, used to populate the initial
        client wizard screen.'''
        return self.update('defaultExpression')
    @property
    def description(self):
        '''The static descriptive strings used in alarms.'''
        return self.update('description')

    
    
    def AcknowledgeAlarm(self, alarm, entity):
        '''Acknowledge the alarm on a managed entity. The actions associated with the
        alarm will not fire until the alarm's next distinct occurrence; that is, until
        after the alarm has entered the green or gray states at least once. Calling
        this method on an acknowledged or non-triggered alarm.
        
        :param alarm: The Alarm to acknowledge.
        
        :param entity: The ManagedEntity for which to acknowledge the Alarm.
        
        '''
        return self.delegate("AcknowledgeAlarm")(alarm, entity)
    
    def AreAlarmActionsEnabled(self, entity):
        '''Returns true if alarm actions are enabled on the specified managed entity.
        
        :param entity: The managed entity to look up.
        
        '''
        return self.delegate("AreAlarmActionsEnabled")(entity)
    
    def CreateAlarm(self, entity, spec):
        '''Creates an alarm.Creates an alarm.
        
        :param entity: The entity with which the alarm is associated.
        
        :param spec: The specification for the new alarm.
        
        '''
        return self.delegate("CreateAlarm")(entity, spec)
    
    def EnableAlarmActions(self, entity, enabled):
        '''Enables or disables alarms on the specified managed entity.
        
        :param entity: The managed entity on which to set a schedule.
        
        :param enabled: true, if alarms are enabled during the schedule.
        
        '''
        return self.delegate("EnableAlarmActions")(entity, enabled)
    
    def GetAlarm(self, entity=None):
        '''Available alarms defined on the entity. These alarms do not include any
        inherited alarms; that is, alarms associated with parent entities.
        
        :param entity: The entity. If not set, alarms are returned for all visible entities.
        
        '''
        return self.delegate("GetAlarm")(entity)
    
    def GetAlarmState(self, entity):
        '''The state of instantiated alarms on the entity.
        
        :param entity: The entity.
        
        '''
        return self.delegate("GetAlarmState")(entity)



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def FileInfo(vim, *args, **kwargs):
    '''This data object type contains rudimentary information about a file in a
    datastore. The information here is not meant to cover all information in
    traditional file systems, but rather to provide sufficient information for
    files that are associated with virtual machines. Derived types describe the
    known file types for a datastore.'''

    obj = vim.client.factory.create('{urn:vim25}FileInfo')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 1:
        raise IndexError('Expected at least 2 arguments got: %d' % len(args))

    required = [ 'path' ]
    optional = [ 'fileSize', 'modification', 'owner', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.managed_entity import ManagedEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class ComputeResource(ManagedEntity):
    '''Represents a set of physical compute resources for a set of virtual
    machines.The base type ComputeResource, when instantiated by calling
    AddStandaloneHost_Task, represents a single host. The subclass
    ClusterComputeResource represents a cluster of hosts and adds distributed
    management features such as availability and resource scheduling.A
    ComputeResource always has a root ResourcePool associated with it. Certain
    types of clusters such as those with VMware DRS enabled and standalone hosts
    (ESX Server 3) support the creation of ResourcePool hierarchies.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.ComputeResource):
        super(ComputeResource, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def configurationEx(self):
        '''Configuration of the compute resource; applies to both standalone hosts and
        clusters. For a cluster this property will return a ClusterConfigInfoEx object.'''
        return self.update('configurationEx')
    @property
    def datastore(self):
        '''The datastore property is the subset of datastore objects in the datacenter
        available in this ComputeResource.'''
        return self.update('datastore')
    @property
    def environmentBrowser(self):
        '''The environment browser object that identifies the environments that are
        supported on this compute resource.'''
        return self.update('environmentBrowser')
    @property
    def host(self):
        '''List of hosts that are part of this compute resource. If the compute resource
        is a standalone type, then this list contains just one element.'''
        return self.update('host')
    @property
    def network(self):
        '''The subset of network objects available in the datacenter that is available in
        this ComputeResource.'''
        return self.update('network')
    @property
    def resourcePool(self):
        '''Reference to root resource pool.'''
        return self.update('resourcePool')
    @property
    def summary(self):
        '''Basic runtime information about a compute resource. This information is used on
        summary screens and in list views.'''
        return self.update('summary')

    
    
    def ReconfigureComputeResource_Task(self, spec, modify):
        '''Change the compute resource configuration.
        
        :param spec: A set of configuration changes to apply to the compute resource. The specification can be a complete set of changes or a partial set of changes, applied incrementally. When invoking reconfigureEx on a cluster, this argument may be a ClusterConfigSpecEx object.
        
        :param modify: Flag to specify whether the specification ("spec") should be applied incrementally. If "modify" is false and the operation succeeds, then the configuration of the cluster matches the specification exactly; in this case any unset portions of the specification will result in unset or default portions of the configuration.
        
        '''
        return self.delegate("ReconfigureComputeResource_Task")(spec, modify)



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def ServiceContent(vim, *args, **kwargs):
    '''The ServiceContent data object defines properties for the ServiceInstance
    managed object. The ServiceInstance itself does not have directly-accessible
    properties because reading the properties of a managed object requires the use
    of a property collector, and the property collector itself is a property of the
    ServiceInstance. For this reason, use the method RetrieveServiceContent to
    retrieve the ServiceContent object.'''

    obj = vim.client.factory.create('{urn:vim25}ServiceContent')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 3:
        raise IndexError('Expected at least 4 arguments got: %d' % len(args))

    required = [ 'about', 'propertyCollector', 'rootFolder' ]
    optional = [ 'accountManager', 'alarmManager', 'authorizationManager',
        'clusterProfileManager', 'complianceManager', 'customFieldsManager',
        'customizationSpecManager', 'diagnosticManager', 'dvSwitchManager',
        'eventManager', 'extensionManager', 'fileManager', 'guestOperationsManager',
        'hostProfileManager', 'ipPoolManager', 'licenseManager', 'localizationManager',
        'ovfManager', 'perfManager', 'scheduledTaskManager', 'searchIndex',
        'sessionManager', 'setting', 'snmpSystem', 'storageResourceManager',
        'taskManager', 'userDirectory', 'viewManager', 'virtualDiskManager',
        'virtualizationManager', 'vmCompatibilityChecker', 'vmProvisioningChecker',
        'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ClusterDasConfigInfoServiceState = Enum(
    'disabled',
    'enabled',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def ApplyProfile(vim, *args, **kwargs):
    '''The ApplyProfile data object is the base class for all data objects that define
    profile configuration data. defines ESX configuration data storage and it
    supports recursive profile definition for the profile plug-in architecture.'''

    obj = vim.client.factory.create('{urn:vim25}ApplyProfile')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 1:
        raise IndexError('Expected at least 2 arguments got: %d' % len(args))

    required = [ 'enabled' ]
    optional = [ 'policy', 'profileTypeName', 'profileVersion', 'property', 'dynamicProperty',
        'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def CustomizationPrefixName(vim, *args, **kwargs):
    '''Specifies that a unique name should be generated by concatenating the base
    string with a number.Virtual machine names are unique across the set of hosts
    and virtual machines known to the VirtualCenter instance. VirtualCenter tracks
    the network names of virtual machines as well as hosts. VMware Tools runs in a
    guest operating system and reports information to VirtualCenter, including the
    network name of the guest.'''

    obj = vim.client.factory.create('{urn:vim25}CustomizationPrefixName')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 1:
        raise IndexError('Expected at least 2 arguments got: %d' % len(args))

    required = [ 'base' ]
    optional = [ 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.extensible_managed_object import ExtensibleManagedObject

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class ScheduledTask(ExtensibleManagedObject):
    '''The scheduled task object.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.ScheduledTask):
        super(ScheduledTask, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def info(self):
        '''Information about the current scheduled task.'''
        return self.update('info')

    
    
    def ReconfigureScheduledTask(self, spec):
        '''Reconfigures the scheduled task properties.
        
        :param spec: The new specification for the scheduled task.
        
        '''
        return self.delegate("ReconfigureScheduledTask")(spec)
    
    def RemoveScheduledTask(self):
        '''Removes the scheduled task.
        
        '''
        return self.delegate("RemoveScheduledTask")()
    
    def RunScheduledTask(self):
        '''Runs the scheduled task immediately. The schedule for future runs remains in
        effect.
        
        '''
        return self.delegate("RunScheduledTask")()



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostInternetScsiHbaNetworkBindingSupportType = Enum(
    'notsupported',
    'optional',
    'required',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def StorageDrsVmConfigInfo(vim, *args, **kwargs):
    '''Storage DRS configuration for a single virtual machine. This makes it possible
    to override the default behavior for an individual virtual machine.NOTE: This
    data object type and all of its methods are experimental and subject to change
    in future releases.'''

    obj = vim.client.factory.create('{urn:vim25}StorageDrsVmConfigInfo')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 0:
        raise IndexError('Expected at least 1 arguments got: %d' % len(args))

    required = [  ]
    optional = [ 'behavior', 'enabled', 'intraVmAffinity', 'intraVmAntiAffinity', 'vm',
        'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.managed_object_view import ManagedObjectView

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class InventoryView(ManagedObjectView):
    '''The InventoryView managed object provides a means of browsing the inventory and
    tracking changes to open folders. This managed object is particularly useful
    for UI clients that display a tree-based navigation panel of the
    inventory.InventoryView maintains the view list of managed object references to
    inventory objects. When you create an inventory view (CreateInventoryView), the
    server initializes the view's object list with a single folder - the root
    folder.InventoryView provides methods to open and close folders in the
    inventory. Use these methods to add and subtract objects from the view list.
    Use the InventoryView together with the PropertyCollector to manage the data
    resulting from OpenInventoryViewFolder and CloseInventoryViewFolder methods. By
    using the PropertyCollector, you have access to the modifications to the view,
    rather than processing the entire view list.For example, you might use the
    following sequence of operations with an InventoryView and the
    PropertyCollector:'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.InventoryView):
        super(InventoryView, self).__init__(core, name=name, ref=ref, type=type)

    

    
    
    def CloseInventoryViewFolder(self, entity):
        '''Notify the server that folder(s) have been closed, and changes for all its
        contained objects should no longer be sent. The associated child objects are
        removed from the view. The containers themselves will still be retained as open
        objects until their parent is closed.Notify the server that folder(s) have been
        closed, and changes for all its contained objects should no longer be sent. The
        associated child objects are removed from the view. The containers themselves
        will still be retained as open objects until their parent is closed.
        
        :param entity: An array of managed object references. Each array entry is a reference to an entity to collapse.
        
        '''
        return self.delegate("CloseInventoryViewFolder")(entity)
    
    def OpenInventoryViewFolder(self, entity):
        '''Adds the child objects of a given managed entity to the view.Adds the child
        objects of a given managed entity to the view.Adds the child objects of a given
        managed entity to the view.
        
        :param entity: An array of managed object references. Each array entry is a reference to an entity to expand. Expands each entity in the order given. If an entity is not in the current view, expands the view as needed.
        
        '''
        return self.delegate("OpenInventoryViewFolder")(entity)